@@ -37,7 +37,7 @@
 #include "build/build_config.h"
 #include "third_party/apple_apsl/CFBase.h"
 
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
 #include "base/ios/ios_util.h"
 #else
 #include "base/mac/mac_util.h"
@@ -235,7 +235,7 @@ void* oom_killer_memalign_purgeable(struct _malloc_zone_t* zone,
 // === Core Foundation CFAllocators ===
 
 bool CanGetContextForCFAllocator() {
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
   return !base::ios::IsRunningOnOrLater(14, 0, 0);
 #else
   return !base::mac::IsOSLaterThan12_DontCallThis();
