@@ -173,6 +173,19 @@ void MallocZoneFreeDefiniteSize(malloc_zone_t* zone, void* ptr, size_t size) {
   return ShimFreeDefiniteSize(ptr, size, nullptr);
 }
 
+unsigned MallocZoneBatchMalloc(malloc_zone_t* zone,
+                               size_t size,
+                               void** results,
+                               unsigned num_requested) {
+  return ShimBatchMalloc(size, results, num_requested, nullptr);
+}
+
+void MallocZoneBatchFree(malloc_zone_t* zone,
+                         void** to_be_freed,
+                         unsigned num) {
+  return ShimBatchFree(to_be_freed, num, nullptr);
+}
+
 malloc_introspection_t g_mac_malloc_introspection{};
 malloc_zone_t g_mac_malloc_zone{};
 
@@ -285,8 +298,8 @@ void InitializeZone() {
   g_mac_malloc_zone.free = MallocZoneFree;
   g_mac_malloc_zone.realloc = MallocZoneRealloc;
   g_mac_malloc_zone.destroy = MallocZoneDestroy;
-  g_mac_malloc_zone.batch_malloc = nullptr;
-  g_mac_malloc_zone.batch_free = nullptr;
+  g_mac_malloc_zone.batch_malloc = MallocZoneBatchMalloc;
+  g_mac_malloc_zone.batch_free = MallocZoneBatchFree;
   g_mac_malloc_zone.memalign = MallocZoneMemalign;
   g_mac_malloc_zone.free_definite_size = MallocZoneFreeDefiniteSize;
   g_mac_malloc_zone.pressure_relief = nullptr;
