@@ -5,11 +5,11 @@
 #include "base/allocator/partition_allocator/partition_address_space.h"
 
 #include <array>
+#include <cstdint>
 #include <ostream>
 
 #include "base/allocator/partition_allocator/address_pool_manager.h"
 #include "base/allocator/partition_allocator/page_allocator.h"
-#include "base/allocator/partition_allocator/page_allocator_internal.h"
 #include "base/allocator/partition_allocator/partition_alloc_check.h"
 #include "base/allocator/partition_allocator/partition_alloc_constants.h"
 #include "base/bits.h"
@@ -17,7 +17,7 @@
 #include "base/debug/alias.h"
 #include "build/build_config.h"
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
 #include <windows.h>
 #endif
 
@@ -29,7 +29,7 @@ namespace internal {
 
 namespace {
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
 NOINLINE void HandleGigaCageAllocFailureOutOfVASpace() {
   NO_CODE_FOLDING();
   PA_CHECK(false);
@@ -39,7 +39,7 @@ NOINLINE void HandleGigaCageAllocFailureOutOfCommitCharge() {
   NO_CODE_FOLDING();
   PA_CHECK(false);
 }
-#endif  // defined(OS_WIN)
+#endif  // BUILDFLAG(IS_WIN)
 
 NOINLINE void HandleGigaCageAllocFailure() {
   NO_CODE_FOLDING();
@@ -47,7 +47,7 @@ NOINLINE void HandleGigaCageAllocFailure() {
   PA_DEBUG_DATA_ON_STACK("error", static_cast<size_t>(alloc_page_error_code));
   // It's important to easily differentiate these two failures on Windows, so
   // crash with different stacks.
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
   if (alloc_page_error_code == ERROR_NOT_ENOUGH_MEMORY) {
     // The error code says NOT_ENOUGH_MEMORY, but since we only do MEM_RESERVE,
     // it must be VA space exhaustion.
@@ -58,7 +58,7 @@ NOINLINE void HandleGigaCageAllocFailure() {
     // committed (see crbug.com/1101421#c16).
     HandleGigaCageAllocFailureOutOfCommitCharge();
   } else
-#endif  // defined(OS_WIN)
+#endif  // BUILDFLAG(IS_WIN)
   {
     PA_CHECK(false);
   }
@@ -73,9 +73,9 @@ void PartitionAddressSpace::Init() {
   if (IsInitialized())
     return;
 
-  setup_.regular_pool_base_address_ = reinterpret_cast<uintptr_t>(
-      AllocPages(nullptr, kRegularPoolSize, kRegularPoolSize,
-                 base::PageInaccessible, PageTag::kPartitionAlloc));
+  setup_.regular_pool_base_address_ =
+      AllocPages(kRegularPoolSize, kRegularPoolSize, base::PageInaccessible,
+                 PageTag::kPartitionAlloc);
   if (!setup_.regular_pool_base_address_)
     HandleGigaCageAllocFailure();
   PA_DCHECK(!(setup_.regular_pool_base_address_ & (kRegularPoolSize - 1)));
@@ -94,14 +94,13 @@ void PartitionAddressSpace::Init() {
   // is a valid pointer, and having a "forbidden zone" before the BRP pool
   // prevents such a pointer from "sneaking into" the pool.
   const size_t kForbiddenZoneSize = PageAllocationGranularity();
-  void* ptr = AllocPagesWithAlignOffset(
-      nullptr, kBRPPoolSize + kForbiddenZoneSize, kBRPPoolSize,
+  uintptr_t base_address = AllocPagesWithAlignOffset(
+      0, kBRPPoolSize + kForbiddenZoneSize, kBRPPoolSize,
       kBRPPoolSize - kForbiddenZoneSize, base::PageInaccessible,
       PageTag::kPartitionAlloc);
-  if (!ptr)
+  if (!base_address)
     HandleGigaCageAllocFailure();
-  setup_.brp_pool_base_address_ =
-      reinterpret_cast<uintptr_t>(ptr) + kForbiddenZoneSize;
+  setup_.brp_pool_base_address_ = base_address + kForbiddenZoneSize;
   PA_DCHECK(!(setup_.brp_pool_base_address_ & (kBRPPoolSize - 1)));
   setup_.brp_pool_ = internal::AddressPoolManager::GetInstance()->Add(
       setup_.brp_pool_base_address_, kBRPPoolSize);
@@ -113,30 +112,31 @@ void PartitionAddressSpace::Init() {
 
 #if PA_STARSCAN_USE_CARD_TABLE
   // Reserve memory for PCScan quarantine card table.
-  void* requested_address =
-      reinterpret_cast<void*>(setup_.regular_pool_base_address_);
-  char* actual_address = internal::AddressPoolManager::GetInstance()->Reserve(
-      setup_.regular_pool_, requested_address, kSuperPageSize);
+  uintptr_t requested_address = setup_.regular_pool_base_address_;
+  uintptr_t actual_address =
+      internal::AddressPoolManager::GetInstance()->Reserve(
+          setup_.regular_pool_, requested_address, kSuperPageSize);
   PA_CHECK(requested_address == actual_address)
       << "QuarantineCardTable is required to be allocated at the beginning of "
          "the regular pool";
 #endif  // PA_STARSCAN_USE_CARD_TABLE
 }
 
-void PartitionAddressSpace::InitConfigurablePool(void* address, size_t size) {
+void PartitionAddressSpace::InitConfigurablePool(uintptr_t pool_base,
+                                                 size_t size) {
   // The ConfigurablePool must only be initialized once.
   PA_CHECK(!IsConfigurablePoolInitialized());
 
   // The other Pools must be initialized first.
   Init();
 
-  PA_CHECK(address);
+  PA_CHECK(pool_base);
   PA_CHECK(size <= kConfigurablePoolMaxSize);
   PA_CHECK(size >= kConfigurablePoolMinSize);
   PA_CHECK(bits::IsPowerOfTwo(size));
-  PA_CHECK(reinterpret_cast<uintptr_t>(address) % size == 0);
+  PA_CHECK(pool_base % size == 0);
 
-  setup_.configurable_pool_base_address_ = reinterpret_cast<uintptr_t>(address);
+  setup_.configurable_pool_base_address_ = pool_base;
   setup_.configurable_pool_base_mask_ = ~(size - 1);
 
   setup_.configurable_pool_ = internal::AddressPoolManager::GetInstance()->Add(
@@ -145,13 +145,11 @@ void PartitionAddressSpace::InitConfigurablePool(void* address, size_t size) {
 }
 
 void PartitionAddressSpace::UninitForTesting() {
-  FreePages(reinterpret_cast<void*>(setup_.regular_pool_base_address_),
-            kRegularPoolSize);
+  FreePages(setup_.regular_pool_base_address_, kRegularPoolSize);
   // For BRP pool, the allocation region includes a "forbidden zone" before the
   // pool.
   const size_t kForbiddenZoneSize = PageAllocationGranularity();
-  FreePages(reinterpret_cast<void*>(setup_.brp_pool_base_address_ -
-                                    kForbiddenZoneSize),
+  FreePages(setup_.brp_pool_base_address_ - kForbiddenZoneSize,
             kBRPPoolSize + kForbiddenZoneSize);
   // Do not free pages for the configurable pool, because its memory is owned
   // by someone else, but deinitialize it nonetheless.
