@@ -18,11 +18,11 @@
 #include "base/memory/tagging.h"
 #include "build/build_config.h"
 
-#if defined(OS_APPLE) && defined(ARCH_CPU_64_BITS)
+#if BUILDFLAG(IS_APPLE) && defined(ARCH_CPU_64_BITS)
 #include <mach/vm_page_size.h>
 #endif
 
-namespace base {
+namespace partition_alloc::internal {
 
 // Size of a cache line. Not all CPUs in the world have a 64 bytes cache line
 // size, but as of 2021, most do. This is in particular the case for almost all
@@ -59,7 +59,7 @@ PAGE_ALLOCATOR_CONSTANTS_DECLARE_CONSTEXPR ALWAYS_INLINE size_t
 PartitionPageShift() {
   return 18;  // 256 KiB
 }
-#elif defined(OS_APPLE) && defined(ARCH_CPU_64_BITS)
+#elif BUILDFLAG(IS_APPLE) && defined(ARCH_CPU_64_BITS)
 PAGE_ALLOCATOR_CONSTANTS_DECLARE_CONSTEXPR ALWAYS_INLINE size_t
 PartitionPageShift() {
   return vm_page_shift + 2;
@@ -212,16 +212,26 @@ constexpr size_t kSuperPageBaseMask = ~kSuperPageOffsetMask & kMemTagUnmask;
 #if defined(PA_HAS_64_BITS_POINTERS)
 // The Configurable Pool is only available in 64-bit mode
 constexpr size_t kNumPools = 3;
+
+#if BUILDFLAG(IS_MAC)
+// Special-case macOS. Contrary to other platforms, there is no sandbox limit
+// there, meaning that a single renderer could "happily" consume >8GiB. So the
+// 8GiB pool size is a regression. Make the limit higher on this platform only
+// to be consistent with previous behavior. See crbug.com/1232567 for details.
+constexpr size_t kPoolMaxSize = 16 * kGiB;
+#else
 constexpr size_t kPoolMaxSize = 8 * kGiB;
+#endif  // BUILDFLAG(IS_MAC)
+
 #else
 constexpr size_t kNumPools = 2;
 constexpr size_t kPoolMaxSize = 4 * kGiB;
 #endif
 constexpr size_t kMaxSuperPagesInPool = kPoolMaxSize / kSuperPageSize;
 
-static constexpr internal::pool_handle kRegularPoolHandle = 1;
-static constexpr internal::pool_handle kBRPPoolHandle = 2;
-static constexpr internal::pool_handle kConfigurablePoolHandle = 3;
+static constexpr pool_handle kRegularPoolHandle = 1;
+static constexpr pool_handle kBRPPoolHandle = 2;
+static constexpr pool_handle kConfigurablePoolHandle = 3;
 
 // Slots larger than this size will not receive MTE protection. Pages intended
 // for allocations larger than this constant should not be backed with PROT_MTE
@@ -361,18 +371,11 @@ constexpr size_t kBitsPerSizeT = sizeof(void*) * CHAR_BIT;
 // PartitionPurgeDecommitEmptySlotSpans flag will eagerly decommit all entries
 // in the ring buffer, so with periodic purge enabled, this typically happens
 // every few seconds.
-#if defined(OS_LINUX) || defined(OS_APPLE)
-// Set to a higher value on Linux and macOS, to assess impact on performance
-// bots. This roughly halves the number of syscalls done during a speedometer
-// 2.0 run on these platforms.
-constexpr size_t kMaxFreeableSpans = std::numeric_limits<int8_t>::max();
-#else
-constexpr size_t kMaxFreeableSpans = 16;
-#endif
-
-constexpr int kEmptyCacheIndexBits = 8;
-// Has to fit into SlotSpanMetadata::empty_cache_index.
-static_assert(kMaxFreeableSpans < (1 << (kEmptyCacheIndexBits - 1)), "");
+constexpr size_t kEmptyCacheIndexBits = 7;
+// kMaxFreeableSpans is the buffer size, but is never used as an index value,
+// hence <= is appropriate.
+constexpr size_t kMaxFreeableSpans = 1 << kEmptyCacheIndexBits;
+constexpr size_t kDefaultEmptySlotSpanRingSize = 16;
 
 // If the total size in bytes of allocated but not committed pages exceeds this
 // value (probably it is a "out of virtual address space" crash), a special
@@ -406,6 +409,70 @@ enum PartitionAllocFlags {
   PartitionAllocLastFlag = PartitionAllocFastPathOrReturnNull
 };
 
+}  // namespace partition_alloc::internal
+
+namespace base {
+
+// TODO(https://crbug.com/1288247): Remove these 'using' declarations once
+// the migration to the new namespaces gets done.
+using ::partition_alloc::internal::DirectMapAllocationGranularity;
+using ::partition_alloc::internal::DirectMapAllocationGranularityOffsetMask;
+using ::partition_alloc::internal::DirectMapAllocationGranularityShift;
+#if HAS_MEMORY_TAGGING
+using ::partition_alloc::internal::HasOverflowTag;
+#endif  // HAS_MEMORY_TAGGING
+using ::partition_alloc::internal::kBitsPerSizeT;
+using ::partition_alloc::internal::kBRPPoolHandle;
+using ::partition_alloc::internal::kConfigurablePoolHandle;
+using ::partition_alloc::internal::kDefaultEmptySlotSpanRingSize;
+using ::partition_alloc::internal::kEmptyCacheIndexBits;
+using ::partition_alloc::internal::kFreedByte;
+using ::partition_alloc::internal::kGiB;
+using ::partition_alloc::internal::kInvalidBucketSize;
+using ::partition_alloc::internal::kMaxBucketed;
+using ::partition_alloc::internal::kMaxBucketedOrder;
+using ::partition_alloc::internal::kMaxBucketSpacing;
+using ::partition_alloc::internal::kMaxFreeableSpans;
+using ::partition_alloc::internal::kMaxMemoryTaggingSize;
+using ::partition_alloc::internal::kMaxPartitionPagesPerRegularSlotSpan;
+using ::partition_alloc::internal::kMaxSuperPagesInPool;
+using ::partition_alloc::internal::kMaxSupportedAlignment;
+using ::partition_alloc::internal::kMinBucketedOrder;
+using ::partition_alloc::internal::kMinDirectMappedDownsize;
+using ::partition_alloc::internal::kNumBucketedOrders;
+using ::partition_alloc::internal::kNumBuckets;
+using ::partition_alloc::internal::kNumBucketsPerOrder;
+using ::partition_alloc::internal::kNumBucketsPerOrderBits;
+using ::partition_alloc::internal::kNumPools;
+using ::partition_alloc::internal::kPartitionCachelineSize;
+using ::partition_alloc::internal::kPoolMaxSize;
+using ::partition_alloc::internal::kQuarantinedByte;
+using ::partition_alloc::internal::kReasonableSizeOfUnusedPages;
+using ::partition_alloc::internal::kRegularPoolHandle;
+using ::partition_alloc::internal::kSmallestBucket;
+using ::partition_alloc::internal::kSuperPageAlignment;
+using ::partition_alloc::internal::kSuperPageBaseMask;
+using ::partition_alloc::internal::kSuperPageOffsetMask;
+using ::partition_alloc::internal::kSuperPageShift;
+using ::partition_alloc::internal::kSuperPageSize;
+using ::partition_alloc::internal::kUninitializedByte;
+using ::partition_alloc::internal::MaxDirectMapped;
+using ::partition_alloc::internal::MaxRegularSlotSpanSize;
+using ::partition_alloc::internal::MaxSuperPagesInPool;
+using ::partition_alloc::internal::MaxSystemPagesPerRegularSlotSpan;
+using ::partition_alloc::internal::NumPartitionPagesPerSuperPage;
+using ::partition_alloc::internal::NumSystemPagesPerPartitionPage;
+using ::partition_alloc::internal::PartitionAllocFastPathOrReturnNull;
+using ::partition_alloc::internal::PartitionAllocFlags;
+using ::partition_alloc::internal::PartitionAllocLastFlag;
+using ::partition_alloc::internal::PartitionAllocNoHooks;
+using ::partition_alloc::internal::PartitionAllocReturnNull;
+using ::partition_alloc::internal::PartitionAllocZeroFill;
+using ::partition_alloc::internal::PartitionPageBaseMask;
+using ::partition_alloc::internal::PartitionPageOffsetMask;
+using ::partition_alloc::internal::PartitionPageShift;
+using ::partition_alloc::internal::PartitionPageSize;
+
 }  // namespace base
 
 #endif  // BASE_ALLOCATOR_PARTITION_ALLOCATOR_PARTITION_ALLOC_CONSTANTS_H_
