@@ -12,14 +12,15 @@ namespace base {
 namespace internal {
 
 namespace {
-constexpr PartitionOptions kConfig{PartitionOptions::AlignedAlloc::kDisallowed,
-                                   PartitionOptions::ThreadCache::kDisabled,
-                                   PartitionOptions::Quarantine::kDisallowed,
-                                   PartitionOptions::Cookie::kAllowed,
-                                   PartitionOptions::BackupRefPtr::kDisabled,
-                                   PartitionOptions::UseConfigurablePool::kNo,
-                                   PartitionOptions::LazyCommit::kEnabled};
-}
+constexpr PartitionOptions kConfig{
+    PartitionOptions::AlignedAlloc::kDisallowed,
+    PartitionOptions::ThreadCache::kDisabled,
+    PartitionOptions::Quarantine::kDisallowed,
+    PartitionOptions::Cookie::kAllowed,
+    PartitionOptions::BackupRefPtr::kDisabled,
+    PartitionOptions::UseConfigurablePool::kNo,
+};
+}  // namespace
 
 ThreadSafePartitionRoot& PCScanMetadataAllocator() {
   static base::NoDestructor<ThreadSafePartitionRoot> allocator(kConfig);
