@@ -25,7 +25,7 @@
 #include "base/template_util.h"
 #include "build/build_config.h"
 
-#if defined(OS_APPLE) && !HAS_FEATURE(objc_arc)
+#if BUILDFLAG(IS_APPLE) && !HAS_FEATURE(objc_arc)
 #include "base/mac/scoped_block.h"
 #endif
 
@@ -48,7 +48,7 @@
 //                     signature adapters are applied.
 //  StorageTraits<> -- Type traits that determine how a bound argument is
 //                     stored in BindState.
-//  InvokeHelper<> -- Take a Functor + arguments and actully invokes it.
+//  InvokeHelper<> -- Take a Functor + arguments and actually invokes it.
 //                    Handle the differing syntaxes needed for WeakPtr<>
 //                    support.  This is separate from Invoker to avoid creating
 //                    multiple version of Invoker<>.
@@ -56,7 +56,7 @@
 //  BindState<> -- Stores the curried parameters, and is the main entry point
 //                 into the Bind() system.
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
 namespace Microsoft {
 namespace WRL {
 template <typename>
@@ -88,7 +88,9 @@ class UnretainedWrapper {
   T* get() const { return ptr_; }
 
  private:
-  T* ptr_;
+  using ImplType = std::
+      conditional_t<raw_ptr_traits::IsSupportedType<T>::value, raw_ptr<T>, T*>;
+  ImplType ptr_;
 };
 
 // Storage type for std::reference_wrapper so `BindState` can internally store
@@ -106,9 +108,9 @@ class UnretainedRefWrapper {
   T& get() const { return *ptr_; }
 
  private:
-  // This is intentionally a pointer to ensure the Big Rewrite will change this
-  // to raw_ptr.
-  T* const ptr_;
+  using ImplType = std::
+      conditional_t<raw_ptr_traits::IsSupportedType<T>::value, raw_ptr<T>, T*>;
+  ImplType const ptr_;
 };
 
 template <typename T>
@@ -402,7 +404,7 @@ struct FunctorTraits;
 template <typename Functor>
 struct FunctorTraits<Functor,
                      std::enable_if_t<IsCallableObject<Functor>::value &&
-                                      std::is_empty<Functor>::value>> {
+                                      std::is_empty_v<Functor>>> {
   using RunType = ExtractCallableRunType<Functor>;
   static constexpr bool is_method = false;
   static constexpr bool is_nullable = false;
@@ -429,7 +431,7 @@ struct FunctorTraits<R (*)(Args...)> {
   }
 };
 
-#if defined(OS_WIN) && !defined(ARCH_CPU_64_BITS)
+#if BUILDFLAG(IS_WIN) && !defined(ARCH_CPU_64_BITS)
 
 // For functions.
 template <typename R, typename... Args>
@@ -459,9 +461,9 @@ struct FunctorTraits<R(__fastcall*)(Args...)> {
   }
 };
 
-#endif  // defined(OS_WIN) && !defined(ARCH_CPU_64_BITS)
+#endif  // BUILDFLAG(IS_WIN) && !defined(ARCH_CPU_64_BITS)
 
-#if defined(OS_APPLE)
+#if BUILDFLAG(IS_APPLE)
 
 // Support for Objective-C blocks. There are two implementation depending
 // on whether Automated Reference Counting (ARC) is enabled. When ARC is
@@ -516,7 +518,7 @@ struct FunctorTraits<base::mac::ScopedBlock<R (^)(Args...)>> {
 };
 
 #endif  // HAS_FEATURE(objc_arc)
-#endif  // defined(OS_APPLE)
+#endif  // BUILDFLAG(IS_APPLE)
 
 // For methods.
 template <typename R, typename Receiver, typename... Args>
@@ -550,7 +552,7 @@ struct FunctorTraits<R (Receiver::*)(Args...) const> {
   }
 };
 
-#if defined(OS_WIN) && !defined(ARCH_CPU_64_BITS)
+#if BUILDFLAG(IS_WIN) && !defined(ARCH_CPU_64_BITS)
 
 // For __stdcall methods.
 template <typename R, typename Receiver, typename... Args>
@@ -584,7 +586,7 @@ struct FunctorTraits<R (__stdcall Receiver::*)(Args...) const> {
   }
 };
 
-#endif  // defined(OS_WIN) && !defined(ARCH_CPU_64_BITS)
+#endif  // BUILDFLAG(IS_WIN) && !defined(ARCH_CPU_64_BITS)
 
 #ifdef __cpp_noexcept_function_type
 // noexcept makes a distinct function type in C++17.
@@ -656,26 +658,15 @@ using MakeFunctorTraits = FunctorTraits<std::decay_t<Functor>>;
 // StorageTraits<>
 //
 // See description at top of file.
-template <typename T, typename SFINAE = void>
+template <typename T>
 struct StorageTraits {
   using Type = T;
 };
 
-// For T*, conditionally store as UnretainedWrapper<T> for safety. When the Big
-// Rewrite lands, UnretainedWrapper's internal T* field will be rewritten to
-// raw_ptr<T>, transitively providing safety.
-//
-// There is a bit of additional complexity here because raw_ptr<T> does not
-// support pointers to functions or pointers to Objective-C objects - this is
-// why the raw_ptr_traits::IsSupportedType needs to be consulted.
-//
-// TODO(dcheng): It should not be possible to instantiate raw_ptr<T> for
-// unsupported types, as that would allow this trait to be significantly
-// simplified.
+// For T*, store as UnretainedWrapper<T> for safety, as it internally uses
+// raw_ptr<T> (when possible).
 template <typename T>
-struct StorageTraits<
-    T*,
-    std::enable_if_t<raw_ptr_traits::IsSupportedType<T>::value>> {
+struct StorageTraits<T*> {
   using Type = UnretainedWrapper<T>;
 };
 
@@ -715,7 +706,7 @@ struct InvokeHelper<true, ReturnType> {
   // WeakCalls are only supported for functions with a void return type.
   // Otherwise, the function result would be undefined if the WeakPtr<>
   // is invalidated.
-  static_assert(std::is_void<ReturnType>::value,
+  static_assert(std::is_void_v<ReturnType>,
                 "weak_ptrs can only bind to methods without return values");
 
   template <typename Functor, typename BoundWeakPtr, typename... RunArgs>
@@ -746,7 +737,7 @@ struct Invoker<StorageType, R(UnboundArgs...)> {
     // InvokeHelper<>::MakeItSo() call below.
     StorageType* storage = static_cast<StorageType*>(base);
     static constexpr size_t num_bound_args =
-        std::tuple_size<decltype(storage->bound_args_)>::value;
+        std::tuple_size_v<decltype(storage->bound_args_)>;
     return RunImpl(std::move(storage->functor_),
                    std::move(storage->bound_args_),
                    std::make_index_sequence<num_bound_args>(),
@@ -759,7 +750,7 @@ struct Invoker<StorageType, R(UnboundArgs...)> {
     // InvokeHelper<>::MakeItSo() call below.
     const StorageType* storage = static_cast<StorageType*>(base);
     static constexpr size_t num_bound_args =
-        std::tuple_size<decltype(storage->bound_args_)>::value;
+        std::tuple_size_v<decltype(storage->bound_args_)>;
     return RunImpl(storage->functor_, storage->bound_args_,
                    std::make_index_sequence<num_bound_args>(),
                    std::forward<UnboundArgs>(unbound_args)...);
@@ -851,7 +842,7 @@ bool QueryCancellationTraits(const BindStateBase* base,
                              BindStateBase::CancellationQueryMode mode) {
   const BindStateType* storage = static_cast<const BindStateType*>(base);
   static constexpr size_t num_bound_args =
-      std::tuple_size<decltype(storage->bound_args_)>::value;
+      std::tuple_size_v<decltype(storage->bound_args_)>;
   return QueryCancellationTraitsImpl(
       mode, storage->functor_, storage->bound_args_,
       std::make_index_sequence<num_bound_args>());
@@ -861,7 +852,7 @@ bool QueryCancellationTraits(const BindStateBase* base,
 template <typename Functor, typename Receiver, typename... Unused>
 std::enable_if_t<
     !(MakeFunctorTraits<Functor>::is_method &&
-      std::is_pointer<std::decay_t<Receiver>>::value &&
+      std::is_pointer_v<std::decay_t<Receiver>> &&
       IsRefCountedType<std::remove_pointer_t<std::decay_t<Receiver>>>::value)>
 BanUnconstructedRefCountedReceiver(const Receiver& receiver, Unused&&...) {}
 
@@ -872,23 +863,28 @@ void BanUnconstructedRefCountedReceiver() {}
 template <typename Functor, typename Receiver, typename... Unused>
 std::enable_if_t<
     MakeFunctorTraits<Functor>::is_method &&
-    std::is_pointer<std::decay_t<Receiver>>::value &&
+    std::is_pointer_v<std::decay_t<Receiver>> &&
     IsRefCountedType<std::remove_pointer_t<std::decay_t<Receiver>>>::value>
 BanUnconstructedRefCountedReceiver(const Receiver& receiver, Unused&&...) {
   DCHECK(receiver);
 
   // It's error prone to make the implicit first reference to ref-counted types.
-  // In the example below, base::BindOnce() makes the implicit first reference
-  // to the ref-counted Foo. If PostTask() failed or the posted task ran fast
-  // enough, the newly created instance can be destroyed before |oo| makes
-  // another reference.
+  // In the example below, base::BindOnce() would make the implicit first
+  // reference to the ref-counted Foo. If PostTask() failed or the posted task
+  // ran fast enough, the newly created instance could be destroyed before `oo`
+  // makes another reference.
   //   Foo::Foo() {
   //     base::PostTask(FROM_HERE, base::BindOnce(&Foo::Bar, this));
   //   }
   //
   //   scoped_refptr<Foo> oo = new Foo();
   //
-  // Instead of doing like above, please consider adding a static constructor,
+  // Hence, base::Bind{Once,Repeating}() refuses to create the first reference
+  // to ref-counted objects, and DCHECK()s otherwise. As above, that typically
+  // happens around PostTask() in their constructor, and such objects can be
+  // destroyed before `new` returns if the task resolves fast enough.
+  //
+  // Instead of doing the above, please consider adding a static constructor,
   // and keep the first reference alive explicitly.
   //   // static
   //   scoped_refptr<Foo> Foo::Create() {
@@ -900,11 +896,8 @@ BanUnconstructedRefCountedReceiver(const Receiver& receiver, Unused&&...) {
   //   Foo::Foo() {}
   //
   //   scoped_refptr<Foo> oo = Foo::Create();
-  DCHECK(receiver->HasAtLeastOneRef())
-      << "base::Bind{Once,Repeating}() refuses to create the first reference "
-         "to ref-counted objects. That typically happens around PostTask() in "
-         "their constructor, and such objects can be destroyed before `new` "
-         "returns if the task resolves fast enough.";
+  //
+  DCHECK(receiver->HasAtLeastOneRef());
 }
 
 // BindState<>
@@ -1003,10 +996,10 @@ struct MakeBindStateTypeImpl<true, Functor, Receiver, BoundArgs...> {
  private:
   using DecayedReceiver = std::decay_t<Receiver>;
 
-  static_assert(!std::is_array<std::remove_reference_t<Receiver>>::value,
+  static_assert(!std::is_array_v<std::remove_reference_t<Receiver>>,
                 "First bound argument to a method cannot be an array.");
   static_assert(
-      !std::is_pointer<DecayedReceiver>::value ||
+      !std::is_pointer_v<DecayedReceiver> ||
           IsRefCountedType<std::remove_pointer_t<DecayedReceiver>>::value,
       "Receivers may not be raw pointers. If using a raw pointer here is safe"
       " and has no lifetime concerns, use base::Unretained() and document why"
@@ -1017,7 +1010,7 @@ struct MakeBindStateTypeImpl<true, Functor, Receiver, BoundArgs...> {
  public:
   using Type = BindState<
       std::decay_t<Functor>,
-      std::conditional_t<std::is_pointer<DecayedReceiver>::value,
+      std::conditional_t<std::is_pointer_v<DecayedReceiver>,
                          scoped_refptr<std::remove_pointer_t<DecayedReceiver>>,
                          DecayedReceiver>,
       MakeStorageType<BoundArgs>...>;
@@ -1105,25 +1098,25 @@ struct BindArgument {
     template <typename FunctorParamType>
     struct ToParamWithType {
       static constexpr bool kCanBeForwardedToBoundFunctor =
-          std::is_constructible<FunctorParamType, ForwardingType>::value;
+          std::is_constructible_v<FunctorParamType, ForwardingType>;
 
       // If the bound type can't be forwarded then test if `FunctorParamType` is
       // a non-const lvalue reference and a reference to the unwrapped type
       // *could* have been successfully forwarded.
       static constexpr bool kNonConstRefParamMustBeWrapped =
           kCanBeForwardedToBoundFunctor ||
-          !(std::is_lvalue_reference<FunctorParamType>::value &&
-            !std::is_const<std::remove_reference_t<FunctorParamType>>::value &&
-            std::is_convertible<std::decay_t<ForwardingType>&,
-                                FunctorParamType>::value);
+          !(std::is_lvalue_reference_v<FunctorParamType> &&
+            !std::is_const_v<std::remove_reference_t<FunctorParamType>> &&
+            std::is_convertible_v<std::decay_t<ForwardingType>&,
+                                  FunctorParamType>);
 
       // Note that this intentionally drops the const qualifier from
       // `ForwardingType`, to test if it *could* have been successfully
       // forwarded if `Passed()` had been used.
       static constexpr bool kMoveOnlyTypeMustUseBasePassed =
           kCanBeForwardedToBoundFunctor ||
-          !std::is_constructible<FunctorParamType,
-                                 std::decay_t<ForwardingType>&&>::value;
+          !std::is_constructible_v<FunctorParamType,
+                                   std::decay_t<ForwardingType>&&>;
     };
   };
 
@@ -1132,14 +1125,13 @@ struct BindArgument {
     template <typename StorageType>
     struct StoredAs {
       static constexpr bool kBindArgumentCanBeCaptured =
-          std::is_constructible<StorageType, BoundAsType>::value;
+          std::is_constructible_v<StorageType, BoundAsType>;
       // Note that this intentionally drops the const qualifier from
       // `BoundAsType`, to test if it *could* have been successfully bound if
       // `std::move()` had been used.
       static constexpr bool kMoveOnlyTypeMustUseStdMove =
           kBindArgumentCanBeCaptured ||
-          !std::is_constructible<StorageType,
-                                 std::decay_t<BoundAsType>&&>::value;
+          !std::is_constructible_v<StorageType, std::decay_t<BoundAsType>&&>;
     };
   };
 };
@@ -1235,23 +1227,6 @@ template <typename T>
 struct AssertBindArgIsNotBasePassed<PassedWrapper<T>> : public std::false_type {
 };
 
-// Used below in BindImpl to determine whether to use Invoker::Run or
-// Invoker::RunOnce.
-// Note: Simply using `kIsOnce ? &Invoker::RunOnce : &Invoker::Run` does not
-// work, since the compiler needs to check whether both expressions are
-// well-formed. Using `Invoker::Run` with a OnceCallback triggers a
-// static_assert, which is why the ternary expression does not compile.
-// TODO(crbug.com/752720): Remove this indirection once we have `if constexpr`.
-template <typename Invoker>
-constexpr auto GetInvokeFunc(std::true_type) {
-  return Invoker::RunOnce;
-}
-
-template <typename Invoker>
-constexpr auto GetInvokeFunc(std::false_type) {
-  return Invoker::Run;
-}
-
 template <template <typename> class CallbackT,
           typename Functor,
           typename... Args>
@@ -1281,8 +1256,12 @@ decltype(auto) BindImpl(Functor&& functor, Args&&... args) {
   // InvokeFuncStorage, so that we can ensure its type matches to
   // PolymorphicInvoke, to which CallbackType will cast back.
   using PolymorphicInvoke = typename CallbackType::PolymorphicInvoke;
-  PolymorphicInvoke invoke_func =
-      GetInvokeFunc<Invoker>(bool_constant<kIsOnce>());
+  PolymorphicInvoke invoke_func;
+  if constexpr (kIsOnce) {
+    invoke_func = Invoker::RunOnce;
+  } else {
+    invoke_func = Invoker::Run;
+  }
 
   using InvokeFuncStorage = BindStateBase::InvokeFuncStorage;
   return CallbackType(BindState::Create(
@@ -1296,9 +1275,8 @@ decltype(auto) BindImpl(Functor&& functor, Args&&... args) {
 // crashes.
 template <template <typename> class CallbackT,
           typename Signature,
-          std::enable_if_t<std::is_same<CallbackT<Signature>,
-                                        OnceCallback<Signature>>::value>* =
-              nullptr>
+          std::enable_if_t<std::is_same_v<CallbackT<Signature>,
+                                          OnceCallback<Signature>>>* = nullptr>
 OnceCallback<Signature> BindImpl(OnceCallback<Signature> callback) {
   CHECK(callback);
   return callback;
@@ -1306,9 +1284,8 @@ OnceCallback<Signature> BindImpl(OnceCallback<Signature> callback) {
 
 template <template <typename> class CallbackT,
           typename Signature,
-          std::enable_if_t<std::is_same<CallbackT<Signature>,
-                                        OnceCallback<Signature>>::value>* =
-              nullptr>
+          std::enable_if_t<std::is_same_v<CallbackT<Signature>,
+                                          OnceCallback<Signature>>>* = nullptr>
 OnceCallback<Signature> BindImpl(RepeatingCallback<Signature> callback) {
   CHECK(callback);
   return callback;
@@ -1316,8 +1293,8 @@ OnceCallback<Signature> BindImpl(RepeatingCallback<Signature> callback) {
 
 template <template <typename> class CallbackT,
           typename Signature,
-          std::enable_if_t<std::is_same<CallbackT<Signature>,
-                                        RepeatingCallback<Signature>>::value>* =
+          std::enable_if_t<std::is_same_v<CallbackT<Signature>,
+                                          RepeatingCallback<Signature>>>* =
               nullptr>
 RepeatingCallback<Signature> BindImpl(RepeatingCallback<Signature> callback) {
   CHECK(callback);
@@ -1401,7 +1378,7 @@ struct BindUnwrapTraits<internal::PassedWrapper<T>> {
   static T Unwrap(const internal::PassedWrapper<T>& o) { return o.Take(); }
 };
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
 template <typename T>
 struct BindUnwrapTraits<Microsoft::WRL::ComPtr<T>> {
   static T* Unwrap(const Microsoft::WRL::ComPtr<T>& ptr) { return ptr.Get(); }
