@@ -23,8 +23,6 @@
 // Configurable (see the JSONParserOptions type) deviations from the RFC:
 // - Allow trailing commas: "[1,2,]".
 // - Replace invalid Unicode with U+FFFD REPLACEMENT CHARACTER.
-//
-// Non-configurable deviations from the RFC:
 // - Allow "// etc\n" and "/* etc */" C-style comments.
 // - Allow ASCII control characters, including literal (not escaped) NUL bytes
 //   and new lines, within a JSON string.
@@ -50,8 +48,7 @@
 namespace base {
 
 enum JSONParserOptions {
-  // Parses the input strictly according to RFC 8259, except for where noted
-  // above.
+  // Parses the input strictly according to RFC 8259.
   JSON_PARSE_RFC = 0,
 
   // Allows commas to exist after the last element in structures.
@@ -62,6 +59,26 @@ enum JSONParserOptions {
   // not set, invalid code points trigger a hard error and parsing
   // fails.
   JSON_REPLACE_INVALID_CHARACTERS = 1 << 1,
+
+  // Allows both C (/* */) and C++ (//) style comments.
+  JSON_ALLOW_COMMENTS = 1 << 2,
+
+  // Permits unescaped ASCII control characters (such as unescaped \r and \n)
+  // in the range [0x00,0x1F].
+  JSON_ALLOW_CONTROL_CHARS = 1 << 3,
+
+  // Permits \\v vertical tab escapes.
+  JSON_ALLOW_VERT_TAB = 1 << 4,
+
+  // Permits \\xNN escapes as described above.
+  JSON_ALLOW_X_ESCAPES = 1 << 5,
+
+  // This parser historically accepted, without configuration flags,
+  // non-standard JSON extensions. This flag enables that traditional parsing
+  // behavior.
+  JSON_PARSE_CHROMIUM_EXTENSIONS = JSON_ALLOW_COMMENTS |
+                                   JSON_ALLOW_CONTROL_CHARS |
+                                   JSON_ALLOW_VERT_TAB | JSON_ALLOW_X_ESCAPES,
 };
 
 class BASE_EXPORT JSONReader {
@@ -94,7 +111,7 @@ class BASE_EXPORT JSONReader {
   // If |json| is not a properly formed JSON string, returns absl::nullopt.
   static absl::optional<Value> Read(
       StringPiece json,
-      int options = JSON_PARSE_RFC,
+      int options = JSON_PARSE_CHROMIUM_EXTENSIONS,
       size_t max_depth = internal::kAbsoluteMaxDepth);
 
   // Deprecated. Use the Read() method above.
@@ -104,7 +121,7 @@ class BASE_EXPORT JSONReader {
   // convert to a FooValue at the same time.
   static std::unique_ptr<Value> ReadDeprecated(
       StringPiece json,
-      int options = JSON_PARSE_RFC,
+      int options = JSON_PARSE_CHROMIUM_EXTENSIONS,
       size_t max_depth = internal::kAbsoluteMaxDepth);
 
   // Reads and parses |json| like Read(). Returns a ValueWithError, which on
@@ -112,7 +129,7 @@ class BASE_EXPORT JSONReader {
   // the error location if appropriate.
   static ValueWithError ReadAndReturnValueWithError(
       StringPiece json,
-      int options = JSON_PARSE_RFC);
+      int options = JSON_PARSE_CHROMIUM_EXTENSIONS);
 };
 
 }  // namespace base
