@@ -11,7 +11,7 @@
 
 #include "base/base_export.h"
 #include "base/json/json_common.h"
-#include "base/macros.h"
+#include "base/memory/raw_ptr.h"
 
 namespace base {
 
@@ -74,7 +74,7 @@ class BASE_EXPORT JSONWriter {
   bool pretty_print_;
 
   // Where we write JSON data as we generate it.
-  std::string* json_string_;
+  raw_ptr<std::string> json_string_;
 
   // Maximum depth to write.
   const size_t max_depth_;
