@@ -22,13 +22,13 @@
 #include "build/branding_buildflags.h"
 #include "build/build_config.h"
 
-#if !defined(OS_IOS)
+#if !BUILDFLAG(IS_IOS)
 #import <AppKit/AppKit.h>
 #endif
 
 extern "C" {
 CFTypeID SecKeyGetTypeID();
-#if !defined(OS_IOS)
+#if !BUILDFLAG(IS_IOS)
 CFTypeID SecACLGetTypeID();
 CFTypeID SecTrustedApplicationGetTypeID();
 // The NSFont/CTFont toll-free bridging is broken before 10.15.
@@ -40,8 +40,7 @@ Boolean _CFIsObjC(CFTypeID typeID, CFTypeRef obj);
 #endif
 }  // extern "C"
 
-namespace base {
-namespace mac {
+namespace base::mac {
 
 namespace {
 
@@ -51,7 +50,7 @@ bool g_override_am_i_bundled = false;
 bool g_override_am_i_bundled_value = false;
 
 bool UncachedAmIBundled() {
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
   // All apps are bundled on iOS.
   return true;
 #else
@@ -81,7 +80,7 @@ bool AmIBundled() {
 }
 
 void SetOverrideAmIBundled(bool value) {
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
   // It doesn't make sense not to be bundled on iOS.
   if (!value)
     NOTREACHED();
@@ -224,7 +223,7 @@ TYPE_NAME_FOR_CF_TYPE_DEFN(CGColor)
 TYPE_NAME_FOR_CF_TYPE_DEFN(CTFont)
 TYPE_NAME_FOR_CF_TYPE_DEFN(CTRun)
 
-#if !defined(OS_IOS)
+#if !BUILDFLAG(IS_IOS)
 TYPE_NAME_FOR_CF_TYPE_DEFN(SecCertificate)
 TYPE_NAME_FOR_CF_TYPE_DEFN(SecKey)
 TYPE_NAME_FOR_CF_TYPE_DEFN(SecPolicy)
@@ -314,7 +313,7 @@ CF_TO_NS_CAST_DEFN(CFWriteStream, NSOutputStream)
 CF_TO_NS_MUTABLE_CAST_DEFN(String)
 CF_TO_NS_CAST_DEFN(CFURL, NSURL)
 
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
 CF_TO_NS_CAST_DEFN(CTFont, UIFont)
 #else
 // The NSFont/CTFont toll-free bridging is broken before 10.15.
@@ -383,7 +382,7 @@ CF_CAST_DEFN(CGColor)
 CF_CAST_DEFN(CTFontDescriptor)
 CF_CAST_DEFN(CTRun)
 
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
 CF_CAST_DEFN(CTFont)
 #else
 // The NSFont/CTFont toll-free bridging is broken before 10.15.
@@ -419,7 +418,7 @@ CFCastStrict<CTFontRef>(const CFTypeRef& cf_val) {
 }
 #endif
 
-#if !defined(OS_IOS)
+#if !BUILDFLAG(IS_IOS)
 CF_CAST_DEFN(SecACL)
 CF_CAST_DEFN(SecCertificate)
 CF_CAST_DEFN(SecKey)
@@ -499,8 +498,7 @@ bool CFRangeToNSRange(CFRange range, NSRange* range_out) {
   return false;
 }
 
-}  // namespace mac
-}  // namespace base
+}  // namespace base::mac
 
 std::ostream& operator<<(std::ostream& o, const CFStringRef string) {
   return o << base::SysCFStringRefToUTF8(string);
@@ -539,7 +537,7 @@ std::ostream& operator<<(std::ostream& o, SEL selector) {
   return o << NSStringFromSelector(selector);
 }
 
-#if !defined(OS_IOS)
+#if !BUILDFLAG(IS_IOS)
 std::ostream& operator<<(std::ostream& o, NSPoint point) {
   return o << NSStringFromPoint(point);
 }
