@@ -115,6 +115,8 @@ void MessagePumpKqueue::MachPortWatchController::Reset() {
 MessagePumpKqueue::MessagePumpKqueue()
     : kqueue_(kqueue()),
       is_ludicrous_timer_slack_enabled_(base::IsLudicrousTimerSlackEnabled()),
+      ludicrous_timer_slack_was_suspended_(
+          base::IsLudicrousTimerSlackSuspended()),
       weak_factory_(this) {
   PCHECK(kqueue_.is_valid()) << "kqueue";
 
@@ -302,6 +304,51 @@ bool MessagePumpKqueue::WatchFileDescriptor(int fd,
   return true;
 }
 
+bool MessagePumpKqueue::
+    GetIsLudicrousTimerSlackEnabledAndNotSuspendedForTesting() const {
+  return IsLudicrousTimerSlackEnabledAndNotSuspended();
+}
+
+void MessagePumpKqueue::MaybeUpdateWakeupTimerForTesting(
+    const base::TimeTicks& wakeup_time) {
+  MaybeUpdateWakeupTimer(wakeup_time);
+}
+
+void MessagePumpKqueue::SetWakeupTimerEvent(const base::TimeTicks& wakeup_time,
+                                            bool use_slack,
+                                            kevent64_s* timer_event) {
+  // The ident of the wakeup timer. There's only the one timer as the pair
+  // (ident, filter) is the identity of the event.
+  constexpr uint64_t kWakeupTimerIdent = 0x0;
+  timer_event->ident = kWakeupTimerIdent;
+  timer_event->filter = EVFILT_TIMER;
+  if (wakeup_time == base::TimeTicks::Max()) {
+    timer_event->flags = EV_DELETE;
+  } else {
+    timer_event->filter = EVFILT_TIMER;
+    // This updates the timer if it already exists in |kqueue_|.
+    timer_event->flags = EV_ADD | EV_ONESHOT;
+
+    // Specify the sleep in microseconds to avoid undersleeping due to
+    // numeric problems. The sleep is computed from TimeTicks::Now rather than
+    // NextWorkInfo::recent_now because recent_now is strictly earlier than
+    // current wall-clock. Using an earlier wall clock time  to compute the
+    // delta to the next wakeup wall-clock time would guarantee oversleep.
+    // If wakeup_time is in the past, the delta below will be negative and the
+    // timer is set immediately.
+    timer_event->fflags = NOTE_USECONDS;
+    timer_event->data = (wakeup_time - base::TimeTicks::Now()).InMicroseconds();
+
+    if (use_slack) {
+      // Specify ludicrous slack when the experiment is enabled and hasn't
+      // been process-locally suspended.
+      // See "man kqueue" in recent macOSen for documentation.
+      timer_event->fflags |= NOTE_LEEWAY;
+      timer_event->ext[1] = GetLudicrousTimerSlack().InMicroseconds();
+    }
+  }
+}
+
 bool MessagePumpKqueue::StopWatchingMachPort(
     MachPortWatchController* controller) {
   mach_port_t port = controller->port();
@@ -383,8 +430,7 @@ bool MessagePumpKqueue::DoInternalWork(Delegate* delegate,
   int flags = immediate ? KEVENT_FLAG_IMMEDIATE : 0;
 
   if (!immediate) {
-    if (scheduled_wakeup_time_ != next_work_info->delayed_run_time)
-      UpdateWakeupTimer(next_work_info->delayed_run_time);
+    MaybeUpdateWakeupTimer(next_work_info->delayed_run_time);
     DCHECK_EQ(scheduled_wakeup_time_, next_work_info->delayed_run_time);
     delegate->BeforeWait();
   }
@@ -487,51 +533,40 @@ bool MessagePumpKqueue::ProcessEvents(Delegate* delegate, int count) {
   return did_work;
 }
 
-void MessagePumpKqueue::UpdateWakeupTimer(const base::TimeTicks& wakeup_time) {
-  DCHECK_NE(wakeup_time, scheduled_wakeup_time_);
+void MessagePumpKqueue::MaybeUpdateWakeupTimer(
+    const base::TimeTicks& wakeup_time) {
+  // Read the state of the suspend flag only once in this function to avoid
+  // TOCTTOU problems.
+  const bool is_ludicrous_slack_suspended = IsLudicrousTimerSlackSuspended();
+  if (wakeup_time == scheduled_wakeup_time_) {
+    if (scheduled_wakeup_time_ == base::TimeTicks::Max() ||
+        ludicrous_timer_slack_was_suspended_ == is_ludicrous_slack_suspended) {
+      // No change in the timer setting necessary.
+      return;
+    }
+  }
 
-  // The ident of the wakeup timer. There's only the one timer as the pair
-  // (ident, filter) is the identity of the event.
-  constexpr uint64_t kWakeupTimerIdent = 0x0;
+  if (ludicrous_timer_slack_was_suspended_ == is_ludicrous_slack_suspended) {
+    // If there wasn't a suspension toggle, the wakeup time must have changed.
+    DCHECK_NE(wakeup_time, scheduled_wakeup_time_);
+  }
+
+  const bool use_slack =
+      is_ludicrous_timer_slack_enabled_ && !is_ludicrous_slack_suspended;
   if (wakeup_time == base::TimeTicks::Max()) {
-    // Clear the timer.
-    kevent64_s timer{};
-    timer.ident = kWakeupTimerIdent;
-    timer.filter = EVFILT_TIMER;
-    timer.flags = EV_DELETE;
-
-    int rv = ChangeOneEvent(kqueue_, &timer);
-    PCHECK(rv == 0) << "kevent64, delete timer";
-    --event_count_;
+    // If the timer was already reset, don't re-reset it on a suspend toggle.
+    if (scheduled_wakeup_time_ != base::TimeTicks::Max()) {
+      // Clear the timer.
+      kevent64_s timer{};
+      SetWakeupTimerEvent(wakeup_time, use_slack, &timer);
+      int rv = ChangeOneEvent(kqueue_, &timer);
+      PCHECK(rv == 0) << "kevent64, delete timer";
+      --event_count_;
+    }
   } else {
     // Set/reset the timer.
     kevent64_s timer{};
-    timer.ident = kWakeupTimerIdent;
-    timer.filter = EVFILT_TIMER;
-    // This updates the timer if it already exists in |kqueue_|.
-    timer.flags = EV_ADD | EV_ONESHOT;
-
-    // Specify the sleep in microseconds to avoid undersleeping due to
-    // numeric problems. The sleep is computed from TimeTicks::Now rather than
-    // NextWorkInfo::recent_now because recent_now is strictly earlier than
-    // current wall-clock. Using an earlier wall clock time  to compute the
-    // delta to the next wakeup wall-clock time would guarantee oversleep.
-    // If wakeup_time is in the past, the delta below will be negative and the
-    // timer is set immediately.
-    timer.fflags = NOTE_USECONDS;
-    timer.data = (wakeup_time - base::TimeTicks::Now()).InMicroseconds();
-
-    // This odd-looking check is here to validate that message pumps aren't
-    // constructed before the feature flag is initialized.
-    DCHECK_EQ(base::IsLudicrousTimerSlackEnabled(),
-              is_ludicrous_timer_slack_enabled_);
-    if (is_ludicrous_timer_slack_enabled_) {
-      // Specify ludicrous slack when the experiment is enabled.
-      // See "man kqueue" in recent macOSen for documentation.
-      timer.fflags |= NOTE_LEEWAY;
-      timer.ext[1] = GetLudicrousTimerSlack().InMicroseconds();
-    }
-
+    SetWakeupTimerEvent(wakeup_time, use_slack, &timer);
     int rv = ChangeOneEvent(kqueue_, &timer);
     PCHECK(rv == 0) << "kevent64, set timer";
 
@@ -540,7 +575,17 @@ void MessagePumpKqueue::UpdateWakeupTimer(const base::TimeTicks& wakeup_time) {
       ++event_count_;
   }
 
+  ludicrous_timer_slack_was_suspended_ = is_ludicrous_slack_suspended;
   scheduled_wakeup_time_ = wakeup_time;
+
+  // This odd-looking check is here to validate that message pumps aren't
+  // constructed before the feature flag is initialized.
+  DCHECK_EQ(base::IsLudicrousTimerSlackEnabled(),
+            is_ludicrous_timer_slack_enabled_);
+}
+
+bool MessagePumpKqueue::IsLudicrousTimerSlackEnabledAndNotSuspended() const {
+  return is_ludicrous_timer_slack_enabled_ && !IsLudicrousTimerSlackSuspended();
 }
 
 }  // namespace base
