@@ -23,21 +23,21 @@
 #include "build/build_config.h"
 #include "build/chromeos_buildflags.h"
 
-#if defined(OS_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
 #include <sys/vfs.h>
 #define statvfs statfs  // Android uses a statvfs-like statfs struct and call.
 #else
 #include <sys/statvfs.h>
 #endif
 
-#if defined(OS_LINUX) || defined(OS_CHROMEOS)
+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)
 #include <linux/magic.h>
 #include <sys/vfs.h>
 #endif
 
 namespace {
 
-#if !defined(OS_OPENBSD)
+#if !BUILDFLAG(IS_OPENBSD)
 int NumberOfProcessors() {
   // sysconf returns the number of "logical" (not "physical") processors on both
   // Mac and Linux.  So we get the number of max available "logical" processors.
@@ -60,7 +60,7 @@ int NumberOfProcessors() {
 
   int num_cpus = static_cast<int>(res);
 
-#if defined(OS_LINUX) && !defined(OS_CHROMEOS)
+#if BUILDFLAG(IS_LINUX) && !BUILDFLAG(IS_CHROMEOS)
   // Restrict the CPU count based on the process's CPU affinity mask, if
   // available.
   cpu_set_t* cpu_set = CPU_ALLOC(num_cpus);
@@ -70,14 +70,14 @@ int NumberOfProcessors() {
     num_cpus = CPU_COUNT_S(cpu_set_size, cpu_set);
   }
   CPU_FREE(cpu_set);
-#endif // defined(OS_LINUX) && !defined(OS_CHROMEOS
+#endif  // BUILDFLAG(IS_LINUX) && !defined(OS_CHROMEOS
 
   return num_cpus;
 }
 
 base::LazyInstance<base::internal::LazySysInfoValue<int, NumberOfProcessors>>::
     Leaky g_lazy_number_of_processors = LAZY_INSTANCE_INITIALIZER;
-#endif  // !defined(OS_OPENBSD)
+#endif  // !BUILDFLAG(IS_OPENBSD)
 
 int64_t AmountOfVirtualMemory() {
   struct rlimit limit;
@@ -93,7 +93,7 @@ base::LazyInstance<
     base::internal::LazySysInfoValue<int64_t, AmountOfVirtualMemory>>::Leaky
     g_lazy_virtual_memory = LAZY_INSTANCE_INITIALIZER;
 
-#if defined(OS_LINUX) || defined(OS_CHROMEOS)
+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)
 bool IsStatsZeroIfUnlimited(const base::FilePath& path) {
   struct statfs stats;
 
@@ -108,7 +108,7 @@ bool IsStatsZeroIfUnlimited(const base::FilePath& path) {
   }
   return false;
 }
-#endif  // defined(OS_LINUX) || defined(OS_CHROMEOS)
+#endif  // BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)
 
 bool GetDiskSpaceInfo(const base::FilePath& path,
                       int64_t* available_bytes,
@@ -117,7 +117,7 @@ bool GetDiskSpaceInfo(const base::FilePath& path,
   if (HANDLE_EINTR(statvfs(path.value().c_str(), &stats)) != 0)
     return false;
 
-#if defined(OS_LINUX) || defined(OS_CHROMEOS)
+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)
   const bool zero_size_means_unlimited =
       stats.f_blocks == 0 && IsStatsZeroIfUnlimited(path);
 #else
@@ -143,11 +143,11 @@ bool GetDiskSpaceInfo(const base::FilePath& path,
 
 namespace base {
 
-#if !defined(OS_OPENBSD)
+#if !BUILDFLAG(IS_OPENBSD)
 int SysInfo::NumberOfProcessors() {
   return g_lazy_number_of_processors.Get().value();
 }
-#endif  // !defined(OS_OPENBSD)
+#endif  // !BUILDFLAG(IS_OPENBSD)
 
 // static
 int64_t SysInfo::AmountOfVirtualMemory() {
@@ -158,7 +158,7 @@ int64_t SysInfo::AmountOfVirtualMemory() {
 int64_t SysInfo::AmountOfFreeDiskSpace(const FilePath& path) {
   base::ScopedBlockingCall scoped_blocking_call(FROM_HERE,
                                                 base::BlockingType::MAY_BLOCK);
-#if defined(OS_CHROMEOS)
+#if BUILDFLAG(IS_CHROMEOS)
   int64_t ret = GetFreeDiskSpaceFromSpaced(path);
   if (ret != -1)
     return ret;
@@ -176,7 +176,7 @@ int64_t SysInfo::AmountOfTotalDiskSpace(const FilePath& path) {
   base::ScopedBlockingCall scoped_blocking_call(FROM_HERE,
                                                 base::BlockingType::MAY_BLOCK);
 
-#if defined(OS_CHROMEOS)
+#if BUILDFLAG(IS_CHROMEOS)
   int64_t ret = GetTotalDiskSpaceFromSpaced(path);
   if (ret != -1)
     return ret;
@@ -189,7 +189,7 @@ int64_t SysInfo::AmountOfTotalDiskSpace(const FilePath& path) {
   return total;
 }
 
-#if !defined(OS_APPLE) && !defined(OS_ANDROID)
+#if !BUILDFLAG(IS_APPLE) && !BUILDFLAG(IS_ANDROID)
 // static
 std::string SysInfo::OperatingSystemName() {
   struct utsname info;
@@ -199,9 +199,9 @@ std::string SysInfo::OperatingSystemName() {
   }
   return std::string(info.sysname);
 }
-#endif  //! defined(OS_APPLE) && !defined(OS_ANDROID)
+#endif  //! BUILDFLAG(IS_APPLE) && !BUILDFLAG(IS_ANDROID)
 
-#if !defined(OS_APPLE) && !defined(OS_ANDROID) && \
+#if !BUILDFLAG(IS_APPLE) && !BUILDFLAG(IS_ANDROID) && \
     !BUILDFLAG(IS_CHROMEOS_ASH) && !BUILDFLAG(IS_CHROMEOS_LACROS)
 // static
 std::string SysInfo::OperatingSystemVersion() {
@@ -214,7 +214,7 @@ std::string SysInfo::OperatingSystemVersion() {
 }
 #endif
 
-#if !defined(OS_APPLE) && !defined(OS_ANDROID) && \
+#if !BUILDFLAG(IS_APPLE) && !BUILDFLAG(IS_ANDROID) && \
     !BUILDFLAG(IS_CHROMEOS_ASH) && !BUILDFLAG(IS_CHROMEOS_LACROS)
 // static
 void SysInfo::OperatingSystemVersionNumbers(int32_t* major_version,
@@ -239,7 +239,7 @@ void SysInfo::OperatingSystemVersionNumbers(int32_t* major_version,
 }
 #endif
 
-#if !defined(OS_MAC) && !defined(OS_IOS)
+#if !BUILDFLAG(IS_MAC) && !BUILDFLAG(IS_IOS)
 // static
 std::string SysInfo::OperatingSystemArchitecture() {
   struct utsname info;
@@ -257,7 +257,7 @@ std::string SysInfo::OperatingSystemArchitecture() {
   }
   return arch;
 }
-#endif  // !defined(OS_MAC) && !defined(OS_IOS)
+#endif  // !BUILDFLAG(IS_MAC) && !BUILDFLAG(IS_IOS)
 
 // static
 size_t SysInfo::VMAllocationGranularity() {
