@@ -6,7 +6,6 @@
 #define BASE_TASK_SEQUENCE_MANAGER_SEQUENCE_MANAGER_IMPL_H_
 
 #include <deque>
-#include <list>
 #include <map>
 #include <memory>
 #include <set>
@@ -18,6 +17,7 @@
 #include "base/cancelable_callback.h"
 #include "base/containers/circular_deque.h"
 #include "base/debug/crash_logging.h"
+#include "base/feature_list.h"
 #include "base/memory/raw_ptr.h"
 #include "base/memory/scoped_refptr.h"
 #include "base/memory/weak_ptr.h"
@@ -26,7 +26,6 @@
 #include "base/rand_util.h"
 #include "base/run_loop.h"
 #include "base/synchronization/lock.h"
-#include "base/task/common/task_annotator.h"
 #include "base/task/current_thread.h"
 #include "base/task/sequence_manager/associated_thread_id.h"
 #include "base/task/sequence_manager/enqueue_order.h"
@@ -104,12 +103,17 @@ class BASE_EXPORT SequenceManagerImpl
   static std::unique_ptr<SequenceManagerImpl> CreateUnbound(
       SequenceManager::Settings settings);
 
-  // Sets state to eliminate wake ups for canceled tasks, if the
-  // kNoWakeUpsForCanceledTasks feature is enabled. Must be invoked after
-  // FeatureList initialization.
-  static void MaybeSetNoWakeUpsForCanceledTasks();
+  // Initializes the state of all the sequence manager features. Must be invoked
+  // after FeatureList initialization.
+  static void InitializeFeatures();
 
-  // Resets state that eliminates wake ups for canceled tasks.
+  // Sets the global cached state of the NoWakeUpsForCanceledTasks feature
+  // according to its enabled state. Must be invoked after FeatureList
+  // initialization.
+  static void ApplyNoWakeUpsForCanceledTasks();
+
+  // Resets the global cached state of the NoWakeUpsForCanceledTasks feature
+  // according to its default state.
   static void ResetNoWakeUpsForCanceledTasksForTesting();
 
   // SequenceManager implementation:
@@ -168,7 +172,7 @@ class BASE_EXPORT SequenceManagerImpl
   void SetAddQueueTimeToTasks(bool enable);
   void SetTaskExecutionAllowed(bool allowed);
   bool IsTaskExecutionAllowed() const;
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
   void AttachToMessagePump();
 #endif
   bool IsIdleForTesting() override;
