@@ -46,4 +46,7 @@ const Feature kUseBackgroundNativeThreadPool = {
 const Feature kUseFiveMinutesThreadReclaimTime = {
     "UseFiveMinutesThreadReclaimTime", base::FEATURE_DISABLED_BY_DEFAULT};
 
+const BASE_EXPORT Feature kRemoveCanceledTasksInTaskQueue = {
+    "RemoveCanceledTasksInTaskQueue2", base::FEATURE_DISABLED_BY_DEFAULT};
+
 }  // namespace base
