@@ -62,17 +62,17 @@
 #include "build/chromeos_buildflags.h"
 #include "testing/gtest/include/gtest/gtest.h"
 
-#if defined(OS_POSIX)
+#if BUILDFLAG(IS_POSIX)
 #include <fcntl.h>
 
 #include "base/files/file_descriptor_watcher_posix.h"
 #endif
 
-#if defined(OS_APPLE)
+#if BUILDFLAG(IS_APPLE)
 #include "base/mac/scoped_nsautorelease_pool.h"
 #endif
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
 #include "base/strings/string_util_win.h"
 #include "base/win/windows_version.h"
 
@@ -82,7 +82,7 @@
 #undef GetCommandLine
 #endif
 
-#if defined(OS_FUCHSIA)
+#if BUILDFLAG(IS_FUCHSIA)
 #include <lib/fdio/namespace.h>
 #include <lib/zx/job.h>
 #include <lib/zx/time.h>
@@ -154,7 +154,7 @@ TestLauncherTracer* GetTestLauncherTracer() {
   return tracer;
 }
 
-#if defined(OS_FUCHSIA)
+#if BUILDFLAG(IS_FUCHSIA)
 zx_status_t WaitForJobExit(const zx::job& job) {
   zx::time deadline =
       zx::deadline_after(zx::duration(kOutputTimeout.ToZxDuration()));
@@ -168,9 +168,9 @@ zx_status_t WaitForJobExit(const zx::job& job) {
   }
   return ZX_OK;
 }
-#endif  // defined(OS_FUCHSIA)
+#endif  // BUILDFLAG(IS_FUCHSIA)
 
-#if defined(OS_POSIX)
+#if BUILDFLAG(IS_POSIX)
 // Self-pipe that makes it possible to do complex shutdown handling
 // outside of the signal handler.
 int g_shutdown_pipe[2] = { -1, -1 };
@@ -214,7 +214,7 @@ void KillSpawnedTestProcesses() {
   fprintf(stdout, "done.\n");
   fflush(stdout);
 }
-#endif  // defined(OS_POSIX)
+#endif  // BUILDFLAG(IS_POSIX)
 
 // Parses the environment variable var as an Int32.  If it is unset, returns
 // true.  If it is set, unsets it then converts it to Int32 before
@@ -275,7 +275,7 @@ CommandLine PrepareCommandLineForGTest(const CommandLine& command_line,
 
   if (switches.find(switches::kTestLauncherRetriesLeft) == switches.end()) {
     switches[switches::kTestLauncherRetriesLeft] =
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
         base::NumberToWString(
 #else
         base::NumberToString(
@@ -292,7 +292,7 @@ CommandLine PrepareCommandLineForGTest(const CommandLine& command_line,
   // does not really support removing switches well, and trying to do that
   // on a CommandLine with a wrapper is known to break.
   // TODO(phajdan.jr): Give it a try to support CommandLine removing switches.
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
   new_command_line.PrependWrapper(UTF8ToWide(wrapper));
 #else
   new_command_line.PrependWrapper(wrapper);
@@ -310,14 +310,14 @@ int LaunchChildTestProcessWithOptions(const CommandLine& command_line,
                                       TimeDelta timeout,
                                       TestLauncherDelegate* delegate,
                                       bool* was_timeout) {
-#if defined(OS_POSIX)
+#if BUILDFLAG(IS_POSIX)
   // Make sure an option we rely on is present - see LaunchChildGTestProcess.
   DCHECK(options.new_process_group);
 #endif
 
   LaunchOptions new_options(options);
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
   DCHECK(!new_options.job_handle);
 
   win::ScopedHandle job_handle;
@@ -344,7 +344,7 @@ int LaunchChildTestProcessWithOptions(const CommandLine& command_line,
 
     new_options.job_handle = job_handle.Get();
   }
-#elif defined(OS_FUCHSIA)
+#elif BUILDFLAG(IS_FUCHSIA)
   DCHECK(!new_options.job_handle);
 
   // Set the clone policy, deliberately omitting FDIO_SPAWN_CLONE_NAMESPACE so
@@ -407,9 +407,9 @@ int LaunchChildTestProcessWithOptions(const CommandLine& command_line,
   new_options.paths_to_transfer.push_back(
       {kCachePath,
        base::OpenDirectoryHandle(test_cache_dir).TakeChannel().release()});
-#endif  // defined(OS_FUCHSIA)
+#endif  // BUILDFLAG(IS_FUCHSIA)
 
-#if defined(OS_LINUX) || defined(OS_CHROMEOS)
+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)
   // To prevent accidental privilege sharing to an untrusted child, processes
   // are started with PR_SET_NO_NEW_PRIVS. Do not set that here, since this
   // new child will be privileged and trusted.
@@ -424,7 +424,7 @@ int LaunchChildTestProcessWithOptions(const CommandLine& command_line,
     // in the set.
     AutoLock lock(*GetLiveProcessesLock());
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
     // Allow the handle used to capture stdio and stdout to be inherited by the
     // child. Note that this is done under GetLiveProcessesLock() to ensure that
     // only the desired child receives the handle.
@@ -436,7 +436,7 @@ int LaunchChildTestProcessWithOptions(const CommandLine& command_line,
 
     process = LaunchProcess(command_line, new_options);
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
     // Revoke inheritance so that the handle isn't leaked into other children.
     // Note that this is done under GetLiveProcessesLock() to ensure that only
     // the desired child receives the handle.
@@ -473,13 +473,13 @@ int LaunchChildTestProcessWithOptions(const CommandLine& command_line,
     }
   }
 
-#if defined(OS_FUCHSIA)
+#if BUILDFLAG(IS_FUCHSIA)
   zx_status_t wait_status = WaitForJobExit(job_handle);
   if (wait_status != ZX_OK) {
     LOG(ERROR) << "Batch leaked jobs or processes.";
     exit_code = -1;
   }
-#endif  // defined(OS_FUCHSIA)
+#endif  // BUILDFLAG(IS_FUCHSIA)
 
   {
     // Note how we grab the log before issuing a possibly broad process kill.
@@ -487,13 +487,13 @@ int LaunchChildTestProcessWithOptions(const CommandLine& command_line,
     // to do that twice and trigger all kinds of log messages.
     AutoLock lock(*GetLiveProcessesLock());
 
-#if defined(OS_FUCHSIA)
+#if BUILDFLAG(IS_FUCHSIA)
     zx_status_t status = job_handle.kill();
     ZX_CHECK(status == ZX_OK, status);
 
     // Cleanup the data directory.
     CHECK(DeletePathRecursively(child_data_path));
-#elif defined(OS_POSIX)
+#elif BUILDFLAG(IS_POSIX)
     // It is not possible to waitpid() on any leaked sub-processes of the test
     // batch process, since those are not direct children of this process.
     // kill()ing the process-group will return a result indicating whether the
@@ -504,7 +504,7 @@ int LaunchChildTestProcessWithOptions(const CommandLine& command_line,
     // Unconditionally kill the process group, regardless of the batch exit-code
     // until a better solution is available.
     kill(-1 * process.Handle(), SIGKILL);
-#endif  // defined(OS_POSIX)
+#endif  // BUILDFLAG(IS_POSIX)
 
     GetLiveProcesses()->erase(process.Handle());
   }
@@ -545,11 +545,11 @@ FilePath CreateChildTempDirIfSupported(const FilePath& task_temp_dir,
 // temporary directory to |environment|.
 void SetTemporaryDirectory(const FilePath& temp_dir,
                            EnvironmentMap* environment) {
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
   environment->emplace(L"TMP", temp_dir.value());
-#elif defined(OS_APPLE)
+#elif BUILDFLAG(IS_APPLE)
   environment->emplace("MAC_CHROMIUM_TMPDIR", temp_dir.value());
-#elif defined(OS_POSIX) || defined(OS_FUCHSIA)
+#elif BUILDFLAG(IS_POSIX) || BUILDFLAG(IS_FUCHSIA)
   environment->emplace("TMPDIR", temp_dir.value());
 #endif
 }
@@ -573,7 +573,7 @@ ChildProcessResults DoLaunchChildTestProcess(
   if (redirect_stdio) {
     output_file = CreateAndOpenTemporaryStream(&output_filename);
     CHECK(output_file);
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
     // Paint the file so that it will be deleted when all handles are closed.
     if (!FILEToFile(output_file.get()).DeleteOnClose(true)) {
       PLOG(WARNING) << "Failed to mark " << output_filename.AsUTF8Unsafe()
@@ -587,7 +587,7 @@ ChildProcessResults DoLaunchChildTestProcess(
   // Tell the child process to use its designated temporary directory.
   if (!process_temp_dir.empty())
     SetTemporaryDirectory(process_temp_dir, &options.environment);
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
 
   options.inherit_mode = test_launch_options.inherit_mode;
   options.handles_to_inherit = test_launch_options.handles_to_inherit;
@@ -606,7 +606,7 @@ ChildProcessResults DoLaunchChildTestProcess(
     }
   }
 
-#else  // if !defined(OS_WIN)
+#else  // if !BUILDFLAG(IS_WIN)
 
   options.fds_to_remap = test_launch_options.fds_to_remap;
   if (redirect_stdio) {
@@ -618,14 +618,14 @@ ChildProcessResults DoLaunchChildTestProcess(
         std::make_pair(output_file_fd, STDERR_FILENO));
   }
 
-#if !defined(OS_FUCHSIA)
+#if !BUILDFLAG(IS_FUCHSIA)
   options.new_process_group = true;
 #endif
-#if defined(OS_LINUX) || defined(OS_CHROMEOS)
+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)
   options.kill_on_parent_death = true;
 #endif
 
-#endif  // !defined(OS_WIN)
+#endif  // !BUILDFLAG(IS_WIN)
 
   result.exit_code = LaunchChildTestProcessWithOptions(
       command_line, options, test_launch_options.flags, timeout, delegate,
@@ -641,7 +641,7 @@ ChildProcessResults DoLaunchChildTestProcess(
           result.exit_code != 0);
 
     output_file.reset();
-#if !defined(OS_WIN)
+#if !BUILDFLAG(IS_WIN)
     // On Windows, the reset() above is enough to delete the file since it was
     // painted for such after being opened. Lesser platforms require an explicit
     // delete now.
@@ -963,8 +963,7 @@ bool TestLauncher::Run(CommandLine* command_line) {
                                       : command_line))
     return false;
 
-
-#if defined(OS_POSIX)
+#if BUILDFLAG(IS_POSIX)
   CHECK_EQ(0, pipe(g_shutdown_pipe));
 
   struct sigaction action;
@@ -980,7 +979,7 @@ bool TestLauncher::Run(CommandLine* command_line) {
       g_shutdown_pipe[0],
       base::BindRepeating(&TestLauncher::OnShutdownPipeReadable,
                           Unretained(this)));
-#endif  // defined(OS_POSIX)
+#endif  // BUILDFLAG(IS_POSIX)
 
   // Start the watchdog timer.
   watchdog_timer_.Reset();
@@ -1274,9 +1273,9 @@ void TestLauncher::OnTestFinished(const TestResult& original_result) {
             test_broken_count_);
     fflush(stdout);
 
-#if defined(OS_POSIX)
+#if BUILDFLAG(IS_POSIX)
     KillSpawnedTestProcesses();
-#endif  // defined(OS_POSIX)
+#endif  // BUILDFLAG(IS_POSIX)
 
     MaybeSaveSummaryAsJSON({"BROKEN_TEST_EARLY_EXIT"});
 
@@ -1558,31 +1557,31 @@ bool TestLauncher::Init(CommandLine* command_line) {
   // Operating systems (sorted alphabetically).
   // Note that they can deliberately overlap, e.g. OS_LINUX is a subset
   // of OS_POSIX.
-#if defined(OS_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
   results_tracker_.AddGlobalTag("OS_ANDROID");
 #endif
 
-#if defined(OS_APPLE)
+#if BUILDFLAG(IS_APPLE)
   results_tracker_.AddGlobalTag("OS_APPLE");
 #endif
 
-#if defined(OS_BSD)
+#if BUILDFLAG(IS_BSD)
   results_tracker_.AddGlobalTag("OS_BSD");
 #endif
 
-#if defined(OS_FREEBSD)
+#if BUILDFLAG(IS_FREEBSD)
   results_tracker_.AddGlobalTag("OS_FREEBSD");
 #endif
 
-#if defined(OS_FUCHSIA)
+#if BUILDFLAG(IS_FUCHSIA)
   results_tracker_.AddGlobalTag("OS_FUCHSIA");
 #endif
 
-#if defined(OS_IOS)
+#if BUILDFLAG(IS_IOS)
   results_tracker_.AddGlobalTag("OS_IOS");
 #endif
 
-#if defined(OS_LINUX) || defined(OS_CHROMEOS)
+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)
   results_tracker_.AddGlobalTag("OS_LINUX");
 #endif
 
@@ -1590,27 +1589,27 @@ bool TestLauncher::Init(CommandLine* command_line) {
   results_tracker_.AddGlobalTag("OS_CHROMEOS");
 #endif
 
-#if defined(OS_MAC)
+#if BUILDFLAG(IS_MAC)
   results_tracker_.AddGlobalTag("OS_MAC");
 #endif
 
-#if defined(OS_NACL)
+#if BUILDFLAG(IS_NACL)
   results_tracker_.AddGlobalTag("OS_NACL");
 #endif
 
-#if defined(OS_OPENBSD)
+#if BUILDFLAG(IS_OPENBSD)
   results_tracker_.AddGlobalTag("OS_OPENBSD");
 #endif
 
-#if defined(OS_POSIX)
+#if BUILDFLAG(IS_POSIX)
   results_tracker_.AddGlobalTag("OS_POSIX");
 #endif
 
-#if defined(OS_SOLARIS)
+#if BUILDFLAG(IS_SOLARIS)
   results_tracker_.AddGlobalTag("OS_SOLARIS");
 #endif
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
   results_tracker_.AddGlobalTag("OS_WIN");
 #endif
 
@@ -1975,7 +1974,7 @@ void TestLauncher::OnTestIterationStart() {
   results_tracker_.OnTestIterationStarting();
 }
 
-#if defined(OS_POSIX)
+#if BUILDFLAG(IS_POSIX)
 // I/O watcher for the reading end of the self-pipe above.
 // Terminates any launched child processes and exits the process.
 void TestLauncher::OnShutdownPipeReadable() {
@@ -1989,7 +1988,7 @@ void TestLauncher::OnShutdownPipeReadable() {
   // The signal would normally kill the process, so exit now.
   _exit(1);
 }
-#endif  // defined(OS_POSIX)
+#endif  // BUILDFLAG(IS_POSIX)
 
 void TestLauncher::MaybeSaveSummaryAsJSON(
     const std::vector<std::string>& additional_tags) {
@@ -2022,7 +2021,7 @@ void TestLauncher::OnOutputTimeout() {
   fprintf(stdout, "Still waiting for the following processes to finish:\n");
 
   for (const auto& pair : *GetLiveProcesses()) {
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
     fwprintf(stdout, L"\t%s\n", pair.second.GetCommandLineString().c_str());
 #else
     fprintf(stdout, "\t%s\n", pair.second.GetCommandLineString().c_str());
@@ -2064,7 +2063,7 @@ size_t NumParallelJobs(unsigned int cores_per_job) {
     return 1U;
   }
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
   // Use processors in all groups (Windows splits more than 64 logical
   // processors into groups).
   size_t cores = base::checked_cast<size_t>(
