@@ -6,6 +6,7 @@
 
 #include "base/threading/hang_watcher.h"
 #include "base/trace_event/base_tracing.h"
+#include "build/build_config.h"
 
 #if DCHECK_IS_ON()
 
@@ -21,7 +22,7 @@
 
 // NaCL doesn't support stack sampling and Android is slow at stack sampling and
 // this causes timeouts (crbug.com/959139).
-#if defined(OS_NACL) || defined(OS_ANDROID)
+#if BUILDFLAG(IS_NACL) || BUILDFLAG(IS_ANDROID)
 constexpr bool kCaptureStackTraces = false;
 #else
 // Always disabled when !EXPENSIVE_DCHECKS_ARE_ON() because user-facing builds
