@@ -147,6 +147,11 @@ namespace cc {
 class CompletionEvent;
 class TileTaskManagerImpl;
 }
+namespace chrome {
+#if BUILDFLAG(IS_MAC)
+void DeveloperIDCertificateReauthorizeInApp();
+#endif  // BUILDFLAG(IS_MAC)
+}  // namespace chrome
 namespace chromecast {
 class CrashUtil;
 }
@@ -170,6 +175,7 @@ class BrowserTestBase;
 class CategorizedWorkerPool;
 class DesktopCaptureDevice;
 class DWriteFontCollectionProxy;
+class DWriteFontProxyImpl;
 class EmergencyTraceFinalisationCoordinator;
 class InProcessUtilityThread;
 class NestedMessagePumpAndroid;
@@ -188,6 +194,7 @@ class SynchronousCompositorHost;
 class SynchronousCompositorSyncCallBridge;
 class TextInputClientMac;
 class WaitForProcessesToDumpProfilingInfo;
+class WebContentsImpl;
 class WebContentsViewMac;
 }  // namespace content
 namespace cronet {
@@ -256,7 +263,7 @@ class ScopedIPCSupport;
 }  // namespace mojo
 namespace printing {
 class LocalPrinterHandlerDefault;
-#if defined(OS_MAC)
+#if BUILDFLAG(IS_MAC)
 class PrintBackendServiceImpl;
 #endif
 class PrintBackendServiceManager;
@@ -444,11 +451,15 @@ class BASE_EXPORT ScopedAllowBlocking {
   friend class blink::DiskDataAllocator;
   friend class chromecast::CrashUtil;
   friend class content::BrowserProcessIOThread;
+  friend class content::DWriteFontProxyImpl;
   friend class content::NetworkServiceInstancePrivate;
   friend class content::PepperPrintSettingsManagerImpl;
   friend class content::RenderProcessHostImpl;
   friend class content::RenderWidgetHostViewMac;  // http://crbug.com/121917
   friend class content::ShellPathProvider;
+#if BUILDFLAG(IS_WIN)
+  friend class content::WebContentsImpl;  // http://crbug.com/1262162
+#endif
   friend class content::WebContentsViewMac;
   friend class cronet::CronetPrefsManager;
   friend class cronet::CronetURLRequestContext;
@@ -461,7 +472,7 @@ class BASE_EXPORT ScopedAllowBlocking {
   friend class module_installer::ScopedAllowModulePakLoad;
   friend class mojo::CoreLibraryInitializer;
   friend class printing::LocalPrinterHandlerDefault;
-#if defined(OS_MAC)
+#if BUILDFLAG(IS_MAC)
   friend class printing::PrintBackendServiceImpl;
 #endif
   friend class printing::PrintBackendServiceManager;
@@ -478,6 +489,9 @@ class BASE_EXPORT ScopedAllowBlocking {
 
   friend Profile* ::GetLastProfileMac();  // crbug.com/1176734
   friend bool PathProviderWin(int, FilePath*);
+#if BUILDFLAG(IS_MAC)
+  friend void chrome::DeveloperIDCertificateReauthorizeInApp();
+#endif  // BUILDFLAG(IS_MAC)
   friend bool chromeos::system::IsCoreSchedulingAvailable();
   friend int chromeos::system::NumberOfPhysicalCores();
   friend bool ::HasWaylandDisplay(base::Environment* env);  // crbug.com/1246928
