@@ -5,11 +5,11 @@
 #include "base/vlog.h"
 
 #include <stddef.h>
-#include <algorithm>
-#include <limits>
+
 #include <ostream>
 #include <utility>
 
+#include "base/cxx17_backports.h"
 #include "base/logging.h"
 #include "base/strings/string_number_conversions.h"
 #include "base/strings/string_split.h"
@@ -24,16 +24,17 @@ struct VlogInfo::VmodulePattern {
 
   explicit VmodulePattern(const std::string& pattern);
 
-  VmodulePattern() = default;
+  VmodulePattern();
 
   std::string pattern;
-  int vlog_level = VlogInfo::kDefaultVlogLevel;
-  MatchTarget match_target = MATCH_MODULE;
-  size_t score = 0;
+  int vlog_level;
+  MatchTarget match_target;
 };
 
 VlogInfo::VmodulePattern::VmodulePattern(const std::string& pattern)
-    : pattern(pattern) {
+    : pattern(pattern),
+      vlog_level(VlogInfo::kDefaultVlogLevel),
+      match_target(MATCH_MODULE) {
   // If the pattern contains a {forward,back} slash, we assume that
   // it's meant to be tested against the entire __FILE__ string.
   std::string::size_type first_slash = pattern.find_first_of("\\/");
@@ -41,6 +42,9 @@ VlogInfo::VmodulePattern::VmodulePattern(const std::string& pattern)
     match_target = MATCH_FILE;
 }
 
+VlogInfo::VmodulePattern::VmodulePattern()
+    : vlog_level(VlogInfo::kDefaultVlogLevel), match_target(MATCH_MODULE) {}
+
 VlogInfo::VlogInfo(const std::string& v_switch,
                    const std::string& vmodule_switch,
                    int* min_log_level)
@@ -82,58 +86,29 @@ namespace {
 // (and any -inl suffix).  We avoid using FilePath to minimize the
 // number of dependencies the logging system has.
 base::StringPiece GetModule(base::StringPiece file) {
-  base::StringPiece module = file;
-
-  // Chop off the file extension.
-  base::StringPiece::size_type extension_start = module.rfind('.');
-  module = module.substr(0, extension_start);
-
-  // Chop off the -inl suffix.
-  static constexpr base::StringPiece kInlSuffix("-inl");
-  if (base::EndsWith(module, kInlSuffix))
-    module.remove_suffix(kInlSuffix.size());
-
-  // Chop off the path up to the start of the file name. Using single-character
-  // overload of `base::StringPiece::find_last_of` for speed; this overload does
-  // not build a lookup table.
-  base::StringPiece::size_type last_slash_pos = module.find_last_of('/');
-  if (last_slash_pos != base::StringPiece::npos) {
-    module.remove_prefix(last_slash_pos + 1);
-    return module;
-  }
-  last_slash_pos = module.find_last_of('\\');
+  base::StringPiece module(file);
+  base::StringPiece::size_type last_slash_pos = module.find_last_of("\\/");
   if (last_slash_pos != base::StringPiece::npos)
     module.remove_prefix(last_slash_pos + 1);
+  base::StringPiece::size_type extension_start = module.rfind('.');
+  module = module.substr(0, extension_start);
+  static const char kInlSuffix[] = "-inl";
+  static const int kInlSuffixLen = base::size(kInlSuffix) - 1;
+  if (base::EndsWith(module, kInlSuffix))
+    module.remove_suffix(kInlSuffixLen);
   return module;
 }
 
 }  // namespace
 
-int VlogInfo::GetVlogLevel(base::StringPiece file) {
-  base::AutoLock lock(vmodule_levels_lock_);
+int VlogInfo::GetVlogLevel(base::StringPiece file) const {
   if (!vmodule_levels_.empty()) {
     base::StringPiece module(GetModule(file));
-    for (size_t i = 0; i < vmodule_levels_.size(); i++) {
-      VmodulePattern& it = vmodule_levels_[i];
-
-      const bool kUseFile = it.match_target == VmodulePattern::MATCH_FILE;
-      if (!MatchVlogPattern(kUseFile ? file : module, it.pattern)) {
-        continue;
-      }
-      const int ret = it.vlog_level;
-
-      // Since `it` matched, increase its score because we believe it has a
-      // higher probability of winning next time.
-      if (it.score == std::numeric_limits<size_t>::max()) {
-        for (VmodulePattern& pattern : vmodule_levels_) {
-          pattern.score = 0;
-        }
-      }
-      ++it.score;
-      if (i > 0 && it.score > vmodule_levels_[i - 1].score)
-        std::swap(it, vmodule_levels_[i - 1]);
-
-      return ret;
+    for (const auto& it : vmodule_levels_) {
+      base::StringPiece target(
+          (it.match_target == VmodulePattern::MATCH_FILE) ? file : module);
+      if (MatchVlogPattern(target, it.pattern))
+        return it.vlog_level;
     }
   }
   return GetMaxVlogLevel();
@@ -154,7 +129,7 @@ bool MatchVlogPattern(base::StringPiece string,
   // https://research.swtch.com/glob.
   size_t s = 0, nexts = 0;
   size_t p = 0, nextp = 0;
-  const size_t slen = string.size(), plen = vlog_pattern.size();
+  size_t slen = string.size(), plen = vlog_pattern.size();
   while (s < slen || p < plen) {
     if (p < plen) {
       switch (vlog_pattern[p]) {
