@@ -14,7 +14,7 @@
 #include "net/log/net_log.h"
 #include "net/log/net_log_event_type.h"
 
-#if defined(OS_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
 #include "base/android/build_info.h"
 #endif
 
@@ -24,7 +24,7 @@ namespace {
 
 // Returns a human readable integer from a NetworkHandle.
 int HumanReadableNetworkHandle(NetworkChangeNotifier::NetworkHandle network) {
-#if defined(OS_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
   // On Marshmallow, demunge the NetID to undo munging done in java
   // Network.getNetworkHandle() by shifting away 0xfacade from
   // http://androidxref.com/6.0.1_r10/xref/frameworks/base/core/java/android/net/Network.java#385
