@@ -250,7 +250,7 @@ static const char* FindMimeType(const MimeInfo (&mappings)[num_mappings],
 
 static base::FilePath::StringType StringToFilePathStringType(
     const base::StringPiece& string_piece) {
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
   return base::UTF8ToWide(string_piece);
 #else
   return std::string(string_piece);
