@@ -26,8 +26,8 @@ der::Input IssuingDistributionPointOid() {
   return der::Input(oid);
 }
 
-WARN_UNUSED_RESULT bool NormalizeNameTLV(const der::Input& name_tlv,
-                                         std::string* out_normalized_name) {
+[[nodiscard]] bool NormalizeNameTLV(const der::Input& name_tlv,
+                                    std::string* out_normalized_name) {
   der::Parser parser(name_tlv);
   der::Input name_rdn;
   net::CertErrors unused_errors;
@@ -368,6 +368,18 @@ CRLRevocationStatus CheckCRL(base::StringPiece raw_crl,
                              const base::Time& verify_time,
                              const base::TimeDelta& max_age) {
   DCHECK_LT(target_cert_index, valid_chain.size());
+
+  if (cert_dp.reasons) {
+    // Reason codes are not supported. If the distribution point contains a
+    // subset of reasons then skip it. We aren't interested in subsets of CRLs
+    // and the RFC states that there MUST be a CRL that covers all reasons.
+    return CRLRevocationStatus::UNKNOWN;
+  }
+  if (cert_dp.crl_issuer) {
+    // Indirect CRLs are not supported.
+    return CRLRevocationStatus::UNKNOWN;
+  }
+
   const ParsedCertificate* target_cert = valid_chain[target_cert_index].get();
 
   // 6.3.3 (a) Update the local CRL cache by obtaining a complete CRL, a
@@ -418,10 +430,10 @@ CRLRevocationStatus CheckCRL(base::StringPiece raw_crl,
   //               field in the complete CRL matches cRLIssuer in the DP and
   //               that the complete CRL contains an issuing distribution
   //               point extension with the indirectCRL boolean asserted.
-  if (cert_dp.has_crl_issuer) {
-    // Indirect CRLs are not supported.
-    return CRLRevocationStatus::UNKNOWN;
-  }
+  //
+  // Nothing is done here since distribution points with crlIssuer were skipped
+  // above.
+
   // 6.3.3 (b) (1) Otherwise, verify that the CRL issuer matches the
   //               certificate issuer.
   //
@@ -477,8 +489,10 @@ CRLRevocationStatus CheckCRL(base::StringPiece raw_crl,
         // 5.2.5.  The identical encoding MUST be used in the distributionPoint
         //         fields of the certificate and the CRL.
         // TODO(https://crbug.com/749276): Check other name types?
-        if (!ContainsExactMatchingName(
-                cert_dp.uris,
+        if (!cert_dp.distribution_point_fullname ||
+            !ContainsExactMatchingName(
+                cert_dp.distribution_point_fullname
+                    ->uniform_resource_identifiers,
                 distribution_point_names->uniform_resource_identifiers)) {
           return CRLRevocationStatus::UNKNOWN;
         }
