@@ -42,8 +42,7 @@ TrustStoreChrome::TrustStoreChrome(base::span<const ChromeRootCertInfo> certs,
       cert = x509_util::CreateCryptoBufferFromStaticDataUnsafe(
           cert_info.root_cert_der);
     } else {
-      cert = x509_util::CreateCryptoBuffer(cert_info.root_cert_der.data(),
-                                           cert_info.root_cert_der.size());
+      cert = x509_util::CreateCryptoBuffer(cert_info.root_cert_der);
     }
     CertErrors errors;
     auto parsed = ParsedCertificate::Create(
