@@ -326,6 +326,12 @@ void RecordSameSiteNoneWriteContextMetric(SameSiteNonePartyContextType type) {
   UMA_HISTOGRAM_ENUMERATION("Cookie.SameSiteNone.PartyContext.Write", type);
 }
 
+// Converts CookieSameSite to CookieSameSiteForMetrics by adding 1 to it.
+CookieSameSiteForMetrics CookieSameSiteToCookieSameSiteForMetrics(
+    CookieSameSite enum_in) {
+  return static_cast<CookieSameSiteForMetrics>((static_cast<int>(enum_in) + 1));
+}
+
 }  // namespace
 
 CookieAccessParams::CookieAccessParams(CookieAccessSemantics access_semantics,
@@ -516,17 +522,20 @@ std::unique_ptr<CanonicalCookie> CanonicalCookie::Create(
   if (parsed_cookie.IsSameParty())
     base::UmaHistogramBoolean("Cookie.IsSamePartyValid", is_same_party_valid);
 
-  bool is_partitioned_valid = IsCookiePartitionedValid(parsed_cookie);
+  bool partition_has_nonce = CookiePartitionKey::HasNonce(cookie_partition_key);
+  bool is_partitioned_valid =
+      IsCookiePartitionedValid(parsed_cookie, partition_has_nonce);
   if (!is_partitioned_valid) {
     status->AddExclusionReason(
         CookieInclusionStatus::EXCLUDE_INVALID_PARTITIONED);
   }
 
   // Collect metrics on whether usage of the Partitioned attribute is correct.
+  // Do not include implicit nonce-based partitioned cookies in these metrics.
   if (parsed_cookie.IsPartitioned()) {
     base::UmaHistogramBoolean("Cookie.IsPartitionedValid",
                               is_partitioned_valid);
-  } else {
+  } else if (!partition_has_nonce) {
     cookie_partition_key = absl::nullopt;
   }
 
@@ -542,8 +551,6 @@ std::unique_ptr<CanonicalCookie> CanonicalCookie::Create(
   // Get the port, this will get a default value if a port isn't provided.
   int source_port = url.EffectiveIntPort();
 
-  // TODO(crbug.com/987177) Add partition key if Partitioned is present in the
-  // cookie line.
   std::unique_ptr<CanonicalCookie> cc = base::WrapUnique(new CanonicalCookie(
       parsed_cookie.Name(), parsed_cookie.Value(), cookie_domain, cookie_path,
       creation_time, cookie_expires, creation_time, parsed_cookie.IsSecure(),
@@ -713,8 +720,8 @@ std::unique_ptr<CanonicalCookie> CanonicalCookie::CreateSanitizedCookie(
     status->AddExclusionReason(
         net::CookieInclusionStatus::EXCLUDE_INVALID_SAMEPARTY);
   }
-  if (!IsCookiePartitionedValid(partition_key.has_value(), prefix,
-                                same_party)) {
+  if (!IsCookiePartitionedValid(partition_key.has_value(), prefix, same_party,
+                                CookiePartitionKey::HasNonce(partition_key))) {
     status->AddExclusionReason(
         net::CookieInclusionStatus::EXCLUDE_INVALID_PARTITIONED);
   }
@@ -980,7 +987,7 @@ CookieAccessResult CanonicalCookie::IncludeForRequestURL(
       DCHECK(IsSameParty());
       status.AddExclusionReason(
           CookieInclusionStatus::EXCLUDE_SAMEPARTY_CROSS_PARTY_CONTEXT);
-      FALLTHROUGH;
+      [[fallthrough]];
     case CookieSamePartyStatus::kEnforceSamePartyInclude: {
       status.AddWarningReason(CookieInclusionStatus::WARN_TREATED_AS_SAMEPARTY);
       // Remove any SameSite exclusion reasons, since SameParty overrides
@@ -1080,7 +1087,8 @@ CookieAccessResult CanonicalCookie::IncludeForRequestURL(
           CookieInclusionStatus::
               WARN_CROSS_SITE_REDIRECT_DOWNGRADE_CHANGES_INCLUSION)) {
     UMA_HISTOGRAM_ENUMERATION(
-        "Cookie.CrossSiteRedirectDowngradeChangesInclusion.Read", SameSite());
+        "Cookie.CrossSiteRedirectDowngradeChangesInclusion2.Read",
+        CookieSameSiteToCookieSameSiteForMetrics(SameSite()));
   }
 
   return CookieAccessResult(effective_same_site, status,
@@ -1202,7 +1210,7 @@ CookieAccessResult CanonicalCookie::IsSetPermittedInContext(
       DCHECK(IsSameParty());
       access_result.status.AddExclusionReason(
           CookieInclusionStatus::EXCLUDE_SAMEPARTY_CROSS_PARTY_CONTEXT);
-      FALLTHROUGH;
+      [[fallthrough]];
     case CookieSamePartyStatus::kEnforceSamePartyInclude: {
       DCHECK(IsSameParty());
       access_result.status.AddWarningReason(
@@ -1300,7 +1308,8 @@ CookieAccessResult CanonicalCookie::IsSetPermittedInContext(
           CookieInclusionStatus::
               WARN_CROSS_SITE_REDIRECT_DOWNGRADE_CHANGES_INCLUSION)) {
     UMA_HISTOGRAM_ENUMERATION(
-        "Cookie.CrossSiteRedirectDowngradeChangesInclusion.Write", SameSite());
+        "Cookie.CrossSiteRedirectDowngradeChangesInclusion2.Write",
+        CookieSameSiteToCookieSameSiteForMetrics(SameSite()));
   }
 
   return access_result;
@@ -1383,7 +1392,8 @@ bool CanonicalCookie::IsCanonicalForFromStorage() const {
   if (!IsCookieSamePartyValid(same_party_, secure_, same_site_))
     return false;
 
-  return IsCookiePartitionedValid(IsPartitioned(), prefix, same_party_);
+  return IsCookiePartitionedValid(IsPartitioned(), prefix, same_party_,
+                                  CookiePartitionKey::HasNonce(partition_key_));
 }
 
 bool CanonicalCookie::IsEffectivelySameSiteNone(
@@ -1520,19 +1530,23 @@ bool CanonicalCookie::IsCookieSamePartyValid(bool is_same_party,
 
 // static
 bool CanonicalCookie::IsCookiePartitionedValid(
-    const ParsedCookie& parsed_cookie) {
-  return IsCookiePartitionedValid(parsed_cookie.IsPartitioned(),
-                                  GetCookiePrefix(parsed_cookie.Name()),
-                                  parsed_cookie.IsSameParty());
+    const ParsedCookie& parsed_cookie,
+    bool partition_has_nonce) {
+  return IsCookiePartitionedValid(
+      parsed_cookie.IsPartitioned(), GetCookiePrefix(parsed_cookie.Name()),
+      parsed_cookie.IsSameParty(), partition_has_nonce);
 }
 
 // static
 bool CanonicalCookie::IsCookiePartitionedValid(
     bool is_partitioned,
     CanonicalCookie::CookiePrefix prefix,
-    bool is_same_party) {
+    bool is_same_party,
+    bool partition_has_nonce) {
   if (!is_partitioned)
     return true;
+  if (partition_has_nonce)
+    return true;
   return prefix == CookiePrefix::COOKIE_PREFIX_HOST && !is_same_party;
 }
 
