@@ -36,6 +36,7 @@ CookieMonsterChangeDispatcher::Subscription::Subscription(
     std::string name_key,
     GURL url,
     absl::optional<CookiePartitionKey> cookie_partition_key,
+    const bool first_party_sets_enabled,
     net::CookieChangeCallback callback)
     : change_dispatcher_(std::move(change_dispatcher)),
       domain_key_(std::move(domain_key)),
@@ -43,6 +44,7 @@ CookieMonsterChangeDispatcher::Subscription::Subscription(
       url_(std::move(url)),
       cookie_partition_key_(std::move(cookie_partition_key)),
       callback_(std::move(callback)),
+      first_party_sets_enabled_(first_party_sets_enabled),
       task_runner_(base::ThreadTaskRunnerHandle::Get()) {
   DCHECK(url_.is_valid() || url_.is_empty());
   DCHECK_EQ(url_.is_empty(), domain_key_ == kGlobalDomainKey);
@@ -71,8 +73,8 @@ void CookieMonsterChangeDispatcher::Subscription::DispatchChange(
         cookie_access_delegate &&
         cookie_access_delegate->ShouldTreatUrlAsTrustworthy(url_);
     CookieOptions options = CookieOptions::MakeAllInclusive();
-    CookieSamePartyStatus same_party_status =
-        cookie_util::GetSamePartyStatus(cookie, options);
+    CookieSamePartyStatus same_party_status = cookie_util::GetSamePartyStatus(
+        cookie, options, first_party_sets_enabled_);
     if (!cookie
              .IncludeForRequestURL(
                  url_, options,
@@ -103,8 +105,10 @@ void CookieMonsterChangeDispatcher::Subscription::DoDispatchChange(
 }
 
 CookieMonsterChangeDispatcher::CookieMonsterChangeDispatcher(
-    const CookieMonster* cookie_monster)
-    : cookie_monster_(cookie_monster) {}
+    const CookieMonster* cookie_monster,
+    const bool first_party_sets_enabled)
+    : cookie_monster_(cookie_monster),
+      first_party_sets_enabled_(first_party_sets_enabled) {}
 
 CookieMonsterChangeDispatcher::~CookieMonsterChangeDispatcher() {
   DCHECK_CALLED_ON_VALID_THREAD(thread_checker_);
@@ -145,7 +149,7 @@ CookieMonsterChangeDispatcher::AddCallbackForCookie(
 
   std::unique_ptr<Subscription> subscription = std::make_unique<Subscription>(
       weak_ptr_factory_.GetWeakPtr(), DomainKey(url), NameKey(name), url,
-      cookie_partition_key, std::move(callback));
+      cookie_partition_key, first_party_sets_enabled_, std::move(callback));
 
   LinkSubscription(subscription.get());
   return subscription;
@@ -161,7 +165,7 @@ CookieMonsterChangeDispatcher::AddCallbackForUrl(
   std::unique_ptr<Subscription> subscription = std::make_unique<Subscription>(
       weak_ptr_factory_.GetWeakPtr(), DomainKey(url),
       std::string(kGlobalNameKey), url, cookie_partition_key,
-      std::move(callback));
+      first_party_sets_enabled_, std::move(callback));
 
   LinkSubscription(subscription.get());
   return subscription;
@@ -175,7 +179,7 @@ CookieMonsterChangeDispatcher::AddCallbackForAllChanges(
   std::unique_ptr<Subscription> subscription = std::make_unique<Subscription>(
       weak_ptr_factory_.GetWeakPtr(), std::string(kGlobalDomainKey),
       std::string(kGlobalNameKey), GURL(""), CookiePartitionKey::Todo(),
-      std::move(callback));
+      first_party_sets_enabled_, std::move(callback));
 
   LinkSubscription(subscription.get());
   return subscription;
