@@ -11,7 +11,6 @@
 
 #include "base/callback.h"
 #include "base/callback_list.h"
-#include "base/compiler_specific.h"
 #include "base/containers/linked_list.h"
 #include "base/memory/raw_ptr.h"
 #include "base/memory/scoped_refptr.h"
@@ -33,7 +32,8 @@ class CookieMonsterChangeDispatcher : public CookieChangeDispatcher {
       base::RepeatingCallbackList<void(const CookieChangeInfo&)>;
 
   // Expects |cookie_monster| to outlive this.
-  explicit CookieMonsterChangeDispatcher(const CookieMonster* cookie_monster);
+  CookieMonsterChangeDispatcher(const CookieMonster* cookie_monster,
+                                bool first_party_sets_enabled);
 
   CookieMonsterChangeDispatcher(const CookieMonsterChangeDispatcher&) = delete;
   CookieMonsterChangeDispatcher& operator=(
@@ -51,17 +51,17 @@ class CookieMonsterChangeDispatcher : public CookieChangeDispatcher {
   static std::string DomainKey(const GURL& url);
 
   // net::CookieChangeDispatcher
-  std::unique_ptr<CookieChangeSubscription> AddCallbackForCookie(
+  [[nodiscard]] std::unique_ptr<CookieChangeSubscription> AddCallbackForCookie(
       const GURL& url,
       const std::string& name,
       const absl::optional<CookiePartitionKey>& cookie_partition_key,
-      CookieChangeCallback callback) override WARN_UNUSED_RESULT;
-  std::unique_ptr<CookieChangeSubscription> AddCallbackForUrl(
+      CookieChangeCallback callback) override;
+  [[nodiscard]] std::unique_ptr<CookieChangeSubscription> AddCallbackForUrl(
       const GURL& url,
       const absl::optional<CookiePartitionKey>& cookie_partition_key,
-      CookieChangeCallback callback) override WARN_UNUSED_RESULT;
-  std::unique_ptr<CookieChangeSubscription> AddCallbackForAllChanges(
-      CookieChangeCallback callback) override WARN_UNUSED_RESULT;
+      CookieChangeCallback callback) override;
+  [[nodiscard]] std::unique_ptr<CookieChangeSubscription>
+  AddCallbackForAllChanges(CookieChangeCallback callback) override;
 
   // |notify_global_hooks| is true if the function should run the
   // global hooks in addition to the per-cookie hooks.
@@ -78,6 +78,7 @@ class CookieMonsterChangeDispatcher : public CookieChangeDispatcher {
                  std::string name_key,
                  GURL url,
                  absl::optional<CookiePartitionKey> cookie_partition_key,
+                 const bool first_party_sets_enabled,
                  net::CookieChangeCallback callback);
 
     Subscription(const Subscription&) = delete;
@@ -106,6 +107,7 @@ class CookieMonsterChangeDispatcher : public CookieChangeDispatcher {
     // nullopt means all Partitioned cookies will be ignored.
     const absl::optional<CookiePartitionKey> cookie_partition_key_;
     const net::CookieChangeCallback callback_;
+    const bool first_party_sets_enabled_;
 
     void DoDispatchChange(const CookieChangeInfo& change) const;
 
@@ -155,6 +157,8 @@ class CookieMonsterChangeDispatcher : public CookieChangeDispatcher {
 
   CookieDomainMap cookie_domain_map_;
 
+  const bool first_party_sets_enabled_;
+
   THREAD_CHECKER(thread_checker_);
 
   // Vends weak pointers to subscriptions.
