@@ -33,17 +33,17 @@ class DelayedCookieMonsterChangeDispatcher : public CookieChangeDispatcher {
   ~DelayedCookieMonsterChangeDispatcher() override;
 
   // net::CookieChangeDispatcher
-  std::unique_ptr<CookieChangeSubscription> AddCallbackForCookie(
+  [[nodiscard]] std::unique_ptr<CookieChangeSubscription> AddCallbackForCookie(
       const GURL& url,
       const std::string& name,
       const absl::optional<CookiePartitionKey>& cookie_partition_key,
-      CookieChangeCallback callback) override WARN_UNUSED_RESULT;
-  std::unique_ptr<CookieChangeSubscription> AddCallbackForUrl(
+      CookieChangeCallback callback) override;
+  [[nodiscard]] std::unique_ptr<CookieChangeSubscription> AddCallbackForUrl(
       const GURL& url,
       const absl::optional<CookiePartitionKey>& cookie_partition_key,
-      CookieChangeCallback callback) override WARN_UNUSED_RESULT;
-  std::unique_ptr<CookieChangeSubscription> AddCallbackForAllChanges(
-      CookieChangeCallback callback) override WARN_UNUSED_RESULT;
+      CookieChangeCallback callback) override;
+  [[nodiscard]] std::unique_ptr<CookieChangeSubscription>
+  AddCallbackForAllChanges(CookieChangeCallback callback) override;
 };
 
 class DelayedCookieMonster : public CookieStore {
