@@ -30,6 +30,7 @@
 #include "net/cookies/cookie_constants.h"
 #include "net/cookies/cookie_monster.h"
 #include "net/cookies/cookie_options.h"
+#include "net/cookies/first_party_set_metadata.h"
 #include "net/cookies/same_party_context.h"
 #include "net/http/http_util.h"
 #include "url/gurl.h"
@@ -282,15 +283,14 @@ bool GetCookieDomainWithString(const GURL& url,
                                const std::string& domain_string,
                                std::string* result) {
   const std::string url_host(url.host());
-
-  url::CanonHostInfo ignored;
-  std::string cookie_domain(CanonicalizeHost(domain_string, &ignored));
-
   // If no domain was specified in the domain string, default to a host cookie.
-  // We match IE/Firefox in allowing a domain=IPADDR if it matches the url
-  // ip address hostname exactly.  It should be treated as a host cookie.
+  // We match IE/Firefox in allowing a domain=IPADDR if it matches (case
+  // in-sensitive) the url ip address hostname and ignoring a leading dot if one
+  // exists. It should be treated as a host cookie.
   if (domain_string.empty() ||
-      (url.HostIsIPAddress() && url_host == cookie_domain)) {
+      (url.HostIsIPAddress() &&
+       (base::EqualsCaseInsensitiveASCII(url_host, domain_string) ||
+        base::EqualsCaseInsensitiveASCII("." + url_host, domain_string)))) {
     *result = url_host;
     DCHECK(DomainIsHostOnly(*result));
     return true;
@@ -302,6 +302,8 @@ bool GetCookieDomainWithString(const GURL& url,
       return false;
   }
 
+  url::CanonHostInfo ignored;
+  std::string cookie_domain(CanonicalizeHost(domain_string, &ignored));
   // Get the normalized domain specified in cookie line.
   if (cookie_domain.empty())
     return false;
@@ -737,36 +739,31 @@ bool IsSchemefulSameSiteEnabled() {
   return base::FeatureList::IsEnabled(features::kSchemefulSameSite);
 }
 
-bool IsFirstPartySetsEnabled() {
-  return base::FeatureList::IsEnabled(features::kFirstPartySets);
-}
-
-// Return SamePartyCookieContextType::kCrossParty when:
-// 1) `isolation_info` is not fully populated.
-// 2) `isolation_info.party_context` is null.
-// 3) `cookie_access_delegate.IsContextSamePartyWithSite` returns false.
-SamePartyContext ComputeSamePartyContext(
+void ComputeFirstPartySetMetadataMaybeAsync(
     const SchemefulSite& request_site,
     const IsolationInfo& isolation_info,
     const CookieAccessDelegate* cookie_access_delegate,
-    bool force_ignore_top_frame_party) {
+    bool force_ignore_top_frame_party,
+    base::OnceCallback<void(FirstPartySetMetadata)> callback) {
   if (!isolation_info.IsEmpty() && isolation_info.party_context().has_value() &&
       cookie_access_delegate) {
-    return cookie_access_delegate->ComputeSamePartyContext(
+    cookie_access_delegate->ComputeFirstPartySetMetadataMaybeAsync(
         request_site,
         force_ignore_top_frame_party
             ? nullptr
             : base::OptionalOrNullptr(
                   isolation_info.network_isolation_key().GetTopFrameSite()),
-        isolation_info.party_context().value());
+        isolation_info.party_context().value(), std::move(callback));
+    return;
   }
 
-  return SamePartyContext();
+  std::move(callback).Run(FirstPartySetMetadata());
 }
 
 CookieSamePartyStatus GetSamePartyStatus(const CanonicalCookie& cookie,
-                                         const CookieOptions& options) {
-  if (!IsFirstPartySetsEnabled() || !cookie.IsSameParty() ||
+                                         const CookieOptions& options,
+                                         const bool first_party_sets_enabled) {
+  if (!first_party_sets_enabled || !cookie.IsSameParty() ||
       !options.is_in_nontrivial_first_party_set()) {
     return CookieSamePartyStatus::kNoSamePartyEnforcement;
   }
@@ -779,24 +776,6 @@ CookieSamePartyStatus GetSamePartyStatus(const CanonicalCookie& cookie,
   };
 }
 
-FirstPartySetsContextType ComputeFirstPartySetsContextType(
-    const SchemefulSite& request_site,
-    const IsolationInfo& isolation_info,
-    const CookieAccessDelegate* cookie_access_delegate,
-    bool force_ignore_top_frame_party) {
-  if (!isolation_info.IsEmpty() && isolation_info.party_context().has_value() &&
-      cookie_access_delegate) {
-    return cookie_access_delegate->ComputeFirstPartySetsContextType(
-        request_site,
-        force_ignore_top_frame_party
-            ? absl::nullopt
-            : isolation_info.network_isolation_key().GetTopFrameSite(),
-        isolation_info.party_context().value());
-  }
-
-  return FirstPartySetsContextType::kUnknown;
-}
-
 base::OnceCallback<void(CookieAccessResult)> AdaptCookieAccessResultToBool(
     base::OnceCallback<void(bool)> callback) {
   return base::BindOnce(
