@@ -7,6 +7,7 @@
 
 #include <memory>
 
+#include "net/base/address_list.h"
 #include "net/base/net_export.h"
 #include "net/base/rand_callback.h"
 #include "net/dns/dns_config.h"
@@ -14,6 +15,12 @@
 #include "net/dns/public/dns_config_overrides.h"
 #include "third_party/abseil-cpp/absl/types/optional.h"
 
+namespace url {
+
+class SchemeHostPort;
+
+}  // namespace url
+
 namespace net {
 
 class AddressSorter;
@@ -80,6 +87,11 @@ class NET_EXPORT DnsClient {
   virtual const DnsConfig* GetEffectiveConfig() const = 0;
   virtual const DnsHosts* GetHosts() const = 0;
 
+  // Returns all preset addresses for the specified endpoint, if any are
+  // present in the current effective DnsConfig.
+  virtual absl::optional<AddressList> GetPresetAddrs(
+      const url::SchemeHostPort& endpoint) const = 0;
+
   // Returns null if the current config is not valid.
   virtual DnsTransactionFactory* GetTransactionFactory() = 0;
 
