@@ -13,11 +13,13 @@
 #include "base/check.h"
 #include "base/location.h"
 #include "base/numerics/safe_conversions.h"
+#include "base/ranges/algorithm.h"
 #include "base/stl_util.h"
 #include "base/sys_byteorder.h"
 #include "base/task/single_thread_task_runner.h"
 #include "base/threading/thread_task_runner_handle.h"
 #include "base/time/time.h"
+#include "net/base/address_list.h"
 #include "net/base/io_buffer.h"
 #include "net/base/ip_address.h"
 #include "net/base/net_errors.h"
@@ -27,8 +29,11 @@
 #include "net/dns/dns_session.h"
 #include "net/dns/dns_socket_allocator.h"
 #include "net/dns/dns_util.h"
+#include "net/dns/public/dns_over_https_server_config.h"
 #include "net/dns/resolve_context.h"
+#include "testing/gmock/include/gmock/gmock-matchers.h"
 #include "testing/gtest/include/gtest/gtest.h"
+#include "url/scheme_host_port.h"
 
 namespace net {
 namespace {
@@ -732,6 +737,12 @@ void MockDnsClient::SetTransactionFactoryForTesting(
   NOTREACHED();
 }
 
+absl::optional<AddressList> MockDnsClient::GetPresetAddrs(
+    const url::SchemeHostPort& endpoint) const {
+  EXPECT_THAT(preset_endpoint_, testing::Optional(endpoint));
+  return preset_addrs_;
+}
+
 void MockDnsClient::CompleteDelayedTransactions() {
   factory_->CompleteDelayedTransactions();
 }
@@ -772,4 +783,16 @@ scoped_refptr<DnsSession> MockDnsClient::BuildSession() {
       null_random_callback, nullptr /* net_log */);
 }
 
+std::vector<DnsOverHttpsServerConfig> ParseDohTemplates(
+    std::vector<std::string> server_templates) {
+  std::vector<DnsOverHttpsServerConfig> out;
+  out.reserve(server_templates.size());
+  base::ranges::transform(server_templates, std::back_inserter(out),
+                          [](std::string& server_template) {
+                            return *DnsOverHttpsServerConfig::FromString(
+                                std::move(server_template));
+                          });
+  return out;
+}
+
 }  // namespace net
