@@ -21,6 +21,8 @@
 
 namespace net {
 
+using HttpsRecordPriority = uint16_t;
+
 class AliasFormHttpsRecordRdata;
 class ServiceFormHttpsRecordRdata;
 
@@ -110,7 +112,7 @@ class NET_EXPORT_PRIVATE ServiceFormHttpsRecordRdata : public HttpsRecordRdata {
   bool IsEqual(const HttpsRecordRdata* other) const override;
   bool IsAlias() const override;
 
-  uint16_t priority() const { return priority_; }
+  HttpsRecordPriority priority() const { return priority_; }
   base::StringPiece service_name() const { return service_name_; }
   const std::set<uint16_t>& mandatory_keys() const { return mandatory_keys_; }
   const std::vector<std::string>& alpn_ids() const { return alpn_ids_; }
@@ -132,7 +134,7 @@ class NET_EXPORT_PRIVATE ServiceFormHttpsRecordRdata : public HttpsRecordRdata {
  private:
   static bool IsSupportedKey(uint16_t key);
 
-  const uint16_t priority_;
+  const HttpsRecordPriority priority_;
   const std::string service_name_;
 
   // Supported service parameters.
