@@ -5,6 +5,7 @@
 #ifndef NET_DNS_PUBLIC_DNS_QUERY_TYPE_H_
 #define NET_DNS_PUBLIC_DNS_QUERY_TYPE_H_
 
+#include "base/containers/enum_set.h"
 #include "base/containers/fixed_flat_map.h"
 #include "base/cxx17_backports.h"
 #include "base/strings/string_piece.h"
@@ -15,7 +16,7 @@ namespace net {
 // DNS query type for HostResolver requests.
 // See:
 // https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-4
-enum class DnsQueryType {
+enum class DnsQueryType : uint8_t {
   UNSPECIFIED = 0,
   A,
   AAAA,
@@ -28,6 +29,9 @@ enum class DnsQueryType {
   MAX = HTTPS_EXPERIMENTAL
 };
 
+using DnsQueryTypeSet =
+    base::EnumSet<DnsQueryType, DnsQueryType::UNSPECIFIED, DnsQueryType::MAX>;
+
 constexpr auto kDnsQueryTypes =
     base::MakeFixedFlatMap<DnsQueryType, base::StringPiece>(
         {{DnsQueryType::UNSPECIFIED, "UNSPECIFIED"},
@@ -44,10 +48,14 @@ static_assert(base::size(kDnsQueryTypes) ==
                   static_cast<unsigned>(DnsQueryType::MAX) + 1,
               "All DnsQueryType values should be in kDnsQueryTypes.");
 
-// |true| iff |dns_query_type| is an address-resulting type, convertable to and
-// from net::AddressFamily.
+// `true` iff `dns_query_type` is an address-resulting type, convertible to and
+// from `net::AddressFamily`.
 bool NET_EXPORT IsAddressType(DnsQueryType dns_query_type);
 
+// `true` iff `dns_query_types` contains an address type. `dns_query_types` must
+// be non-empty and must not contain `DnsQueryType::UNSPECIFIED`.
+bool NET_EXPORT HasAddressType(DnsQueryTypeSet dns_query_types);
+
 }  // namespace net
 
 #endif  // NET_DNS_PUBLIC_DNS_QUERY_TYPE_H_
