@@ -8,6 +8,7 @@
 
 #include "base/check_op.h"
 #include "base/no_destructor.h"
+#include "net/dns/public/dns_over_https_server_config.h"
 #include "net/dns/public/util.h"
 
 namespace net {
@@ -266,16 +267,11 @@ DohProviderEntry::DohProviderEntry(
       provider_id_for_histogram(std::move(provider_id_for_histogram)),
       ip_addresses(ParseIPs(ip_strs)),
       dns_over_tls_hostnames(std::move(dns_over_tls_hostnames)),
-      dns_over_https_template(std::move(dns_over_https_template)),
       ui_name(std::move(ui_name)),
       privacy_policy(std::move(privacy_policy)),
       display_globally(display_globally),
       display_countries(std::move(display_countries)),
       logging_level(logging_level) {
-  DCHECK(!this->dns_over_https_template.empty());
-  DCHECK(dns_util::IsValidDohTemplate(this->dns_over_https_template,
-                                      nullptr /* server_method */));
-
   DCHECK(!display_globally || this->display_countries.empty());
   if (display_globally || !this->display_countries.empty()) {
     DCHECK(!this->ui_name.empty());
@@ -285,6 +281,11 @@ DohProviderEntry::DohProviderEntry(
   for (const auto& display_country : this->display_countries) {
     DCHECK_EQ(2u, display_country.size());
   }
+
+  auto parsed_template =
+      DnsOverHttpsServerConfig::FromString(std::move(dns_over_https_template));
+  DCHECK(parsed_template.has_value());  // Template must be valid.
+  doh_server_config = std::move(*parsed_template);
 }
 
 }  // namespace net
