@@ -19,6 +19,10 @@ namespace base {
 class Value;
 }
 
+namespace url {
+class SchemeHostPort;
+}
+
 namespace net {
 
 class HttpAuthHandler;
@@ -165,8 +169,9 @@ class NET_EXPORT_PRIVATE HttpAuth {
   //
   // |disabled_schemes| is the set of schemes that we should not use.
   //
-  // |origin| is used by the NTLM and Negotiation authentication scheme to
-  // construct the service principal name. It is ignored by other schemes.
+  // |scheme_host_port| is used by the NTLM and Negotiation authentication
+  // scheme to construct the service principal name. It is ignored by other
+  // schemes.
   //
   // |ssl_info| is passed through to the scheme specific authentication handlers
   // to use as appropriate.
@@ -176,7 +181,7 @@ class NET_EXPORT_PRIVATE HttpAuth {
       const SSLInfo& ssl_info,
       const NetworkIsolationKey& network_isolation_key,
       Target target,
-      const GURL& origin,
+      const url::SchemeHostPort& scheme_host_port,
       const std::set<Scheme>& disabled_schemes,
       const NetLogWithSource& net_log,
       HostResolver* host_resolver,
