@@ -19,6 +19,7 @@
 #include "base/strings/stringprintf.h"
 #include "base/threading/thread_restrictions.h"
 #include "base/values.h"
+#include "build/build_config.h"
 #include "net/base/net_errors.h"
 #include "net/http/http_auth.h"
 #include "net/http/http_auth_gssapi_posix.h"
@@ -367,10 +368,10 @@ base::NativeLibrary GSSAPISharedLibrary::LoadSharedLibrary(
     num_lib_names = 1;
   } else {
     static const char* const kDefaultLibraryNames[] = {
-#if defined(OS_APPLE)
+#if BUILDFLAG(IS_APPLE)
       "/System/Library/Frameworks/GSS.framework/GSS"
-#elif defined(OS_OPENBSD)
-      "libgssapi.so"          // Heimdal - OpenBSD
+#elif BUILDFLAG(IS_OPENBSD)
+      "libgssapi.so"  // Heimdal - OpenBSD
 #else
       "libgssapi_krb5.so.2",  // MIT Kerberos - FC, Suse10, Debian
       "libgssapi.so.4",       // Heimdal - Suse10, MDK
