@@ -91,16 +91,15 @@ HttpNetworkSessionParams::HttpNetworkSessionParams()
 // attempt to preserve active streams by marking all sessions as going
 // away, rather than explicitly closing them. Streams may still fail due
 // to a generated TCP reset.
-#if defined(OS_ANDROID) || defined(OS_WIN) || defined(OS_IOS)
+#if BUILDFLAG(IS_ANDROID) || BUILDFLAG(IS_WIN) || BUILDFLAG(IS_IOS)
       spdy_go_away_on_ip_change(true),
 #else
       spdy_go_away_on_ip_change(false),
-#endif  // defined(OS_ANDROID) || defined(OS_WIN) || defined(OS_IOS)
+#endif  // BUILDFLAG(IS_ANDROID) || BUILDFLAG(IS_WIN) || BUILDFLAG(IS_IOS)
       enable_http2_settings_grease(false),
       http2_end_stream_with_data_frame(false),
       time_func(&base::TimeTicks::Now),
       enable_http2_alternative_service(false),
-      enable_websocket_over_http2(true),
       enable_quic(true),
       enable_quic_proxies_for_https_urls(false),
       disable_idle_sockets_close_on_memory_pressure(false),
@@ -375,15 +374,6 @@ void HttpNetworkSession::SetServerPushDelegate(
   quic_stream_factory_.set_server_push_delegate(push_delegate_.get());
 }
 
-void HttpNetworkSession::GetSSLConfig(SSLConfig* server_config,
-                                      SSLConfig* proxy_config) const {
-  server_config->alpn_protos = GetAlpnProtos();
-  server_config->application_settings = GetApplicationSettings();
-  server_config->ignore_certificate_errors = params_.ignore_certificate_errors;
-  *proxy_config = *server_config;
-  server_config->early_data_enabled = params_.enable_early_data;
-}
-
 bool HttpNetworkSession::IsQuicEnabled() const {
   return params_.enable_quic;
 }
