@@ -155,10 +155,8 @@ class NET_EXPORT_PRIVATE HttpProxyConnectJob : public ConnectJob,
  private:
   enum State {
     STATE_BEGIN_CONNECT,
-    STATE_TCP_CONNECT,
-    STATE_TCP_CONNECT_COMPLETE,
-    STATE_SSL_CONNECT,
-    STATE_SSL_CONNECT_COMPLETE,
+    STATE_TRANSPORT_CONNECT,
+    STATE_TRANSPORT_CONNECT_COMPLETE,
     STATE_HTTP_PROXY_CONNECT,
     STATE_HTTP_PROXY_CONNECT_COMPLETE,
     STATE_SPDY_PROXY_CREATE_STREAM,
@@ -191,12 +189,9 @@ class NET_EXPORT_PRIVATE HttpProxyConnectJob : public ConnectJob,
 
   // Determine if need to go through TCP or SSL path.
   int DoBeginConnect();
-  // Connecting to HTTP Proxy
+  // Connecting to HTTP or HTTPS Proxy
   int DoTransportConnect();
   int DoTransportConnectComplete(int result);
-  // Connecting to HTTPS Proxy
-  int DoSSLConnect();
-  int DoSSLConnectComplete(int result);
 
   int DoHttpProxyConnect();
   int DoHttpProxyConnectComplete(int result);
@@ -215,8 +210,6 @@ class NET_EXPORT_PRIVATE HttpProxyConnectJob : public ConnectJob,
   void ChangePriorityInternal(RequestPriority priority) override;
   void OnTimedOutInternal() override;
 
-  int HandleConnectResult(int result);
-
   void OnAuthChallenge();
 
   const HostPortPair& GetDestination() const;
