@@ -34,7 +34,6 @@
 #include "net/http/bidirectional_stream_impl.h"
 #include "net/http/http_basic_stream.h"
 #include "net/http/http_network_session.h"
-#include "net/http/http_proxy_client_socket.h"
 #include "net/http/http_request_info.h"
 #include "net/http/http_server_properties.h"
 #include "net/http/http_stream_factory.h"
@@ -90,8 +89,7 @@ base::Value NetLogHttpStreamJobParams(const NetLogSource& source,
   return dict;
 }
 
-// Returns parameters associated with the Proto (with NPN negotiation) of a HTTP
-// stream.
+// Returns parameters associated with the ALPN protocol of a HTTP stream.
 base::Value NetLogHttpStreamProtoParams(NextProto negotiated_protocol) {
   base::Value dict(base::Value::Type::DICTIONARY);
 
@@ -129,10 +127,10 @@ HttpStreamFactory::Job::Job(Delegate* delegate,
       destination_(std::move(destination)),
       origin_url_(origin_url),
       is_websocket_(is_websocket),
-      try_websocket_over_http2_(is_websocket_ &&
-                                origin_url_.SchemeIs(url::kWssScheme) &&
-                                proxy_info_.is_direct() &&
-                                session_->params().enable_websocket_over_http2),
+      try_websocket_over_http2_(
+          is_websocket_ && origin_url_.SchemeIs(url::kWssScheme) &&
+          // TODO(https://crbug.com/1277306): Remove the proxy check.
+          proxy_info_.is_direct()),
       // Don't use IP connection pooling for HTTP over HTTPS proxies. It doesn't
       // get us much, and testing it is more effort than its worth.
       enable_ip_based_pooling_(
@@ -321,14 +319,6 @@ bool HttpStreamFactory::Job::using_spdy() const {
   return using_spdy_;
 }
 
-const SSLConfig& HttpStreamFactory::Job::server_ssl_config() const {
-  return server_ssl_config_;
-}
-
-const SSLConfig& HttpStreamFactory::Job::proxy_ssl_config() const {
-  return proxy_ssl_config_;
-}
-
 const ProxyInfo& HttpStreamFactory::Job::proxy_info() const {
   return proxy_info_;
 }
@@ -728,6 +718,18 @@ int HttpStreamFactory::Job::DoInitConnectionImpl() {
     server_ssl_config_.renego_allowed_for_protos.push_back(kProtoHTTP11);
   }
 
+  server_ssl_config_.alpn_protos = session_->GetAlpnProtos();
+  proxy_ssl_config_.alpn_protos = session_->GetAlpnProtos();
+  server_ssl_config_.application_settings = session_->GetApplicationSettings();
+  proxy_ssl_config_.application_settings = session_->GetApplicationSettings();
+  server_ssl_config_.ignore_certificate_errors =
+      session_->params().ignore_certificate_errors;
+  proxy_ssl_config_.ignore_certificate_errors =
+      session_->params().ignore_certificate_errors;
+
+  // TODO(https://crbug.com/964642): Also enable 0-RTT for TLS proxies.
+  server_ssl_config_.early_data_enabled = session_->params().enable_early_data;
+
   if (using_quic_)
     return DoInitConnectionImplQuic();
 
@@ -912,56 +914,51 @@ int HttpStreamFactory::Job::DoInitConnectionComplete(int result) {
 
   resolve_error_info_ = connection_->resolve_error_info();
 
-  // |result| may be the result of any of the stacked pools. The following
-  // logic is used when determining how to interpret an error.
-  // If |result| < 0:
-  //   and connection_->socket() != NULL, then the SSL handshake ran and it
-  //     is a potentially recoverable error.
-  //   and connection_->socket == NULL and connection_->is_ssl_error() is true,
-  //     then the SSL handshake ran with an unrecoverable error.
-  //   otherwise, the error came from one of the other pools.
-  bool ssl_started = using_ssl_ && (result == OK || connection_->socket() ||
-                                    connection_->is_ssl_error());
-
-  if (ssl_started && result == OK) {
+  // Determine the protocol (HTTP/1.1, HTTP/2, or HTTP/3). This covers both the
+  // origin and some proxy cases. First, if the URL is HTTPS (or WSS), we may
+  // negotiate HTTP/2 or HTTP/3 with the origin. Second, non-tunneled requests
+  // (i.e. HTTP URLs) through an HTTPS or QUIC proxy work by sending the request
+  // to the proxy directly. In that case, this logic also handles the proxy's
+  // negotiated protocol. HTTPS requests are always tunneled, so at most one of
+  // these applies.
+  //
+  // Tunneled requests may also negotiate ALPN at the proxy, but
+  // HttpProxyConnectJob handles ALPN. The resulting StreamSocket will not
+  // report an ALPN protocol.
+  if (result == OK) {
     if (using_quic_) {
-      was_alpn_negotiated_ = true;
-      negotiated_protocol_ = kProtoQUIC;
-    } else {
-      if (connection_->socket()->WasAlpnNegotiated()) {
+      // TODO(davidben): Record these values consistently between QUIC and TCP
+      // below. In the QUIC case, we only record it for origin connections. In
+      // the TCP case, we also record it for non-tunneled, proxied requests.
+      if (using_ssl_) {
         was_alpn_negotiated_ = true;
-        negotiated_protocol_ = connection_->socket()->GetNegotiatedProtocol();
-        net_log_.AddEvent(NetLogEventType::HTTP_STREAM_REQUEST_PROTO, [&] {
-          return NetLogHttpStreamProtoParams(negotiated_protocol_);
-        });
-        if (negotiated_protocol_ == kProtoHTTP2) {
-          if (is_websocket_) {
-            // WebSocket is not supported over a fresh HTTP/2 connection.
-            return ERR_NOT_IMPLEMENTED;
-          }
-
-          using_spdy_ = true;
-        }
+        negotiated_protocol_ = kProtoQUIC;
       }
-    }
-  } else if (proxy_info_.is_secure_http_like() && connection_->socket() &&
-             result == OK) {
-    ProxyClientSocket* proxy_socket =
-        static_cast<ProxyClientSocket*>(connection_->socket());
-    // http://crbug.com/642354
-    if (!proxy_socket->IsConnected())
-      return ERR_CONNECTION_CLOSED;
-    if (proxy_socket->IsUsingSpdy()) {
+    } else if (connection_->socket()->WasAlpnNegotiated()) {
+      // Only connections that use TLS can negotiate ALPN.
+      DCHECK(using_ssl_ || proxy_info_.is_secure_http_like());
       was_alpn_negotiated_ = true;
-      negotiated_protocol_ = proxy_socket->GetProxyNegotiatedProtocol();
-      using_spdy_ = true;
+      negotiated_protocol_ = connection_->socket()->GetNegotiatedProtocol();
+      net_log_.AddEvent(NetLogEventType::HTTP_STREAM_REQUEST_PROTO, [&] {
+        return NetLogHttpStreamProtoParams(negotiated_protocol_);
+      });
+      if (negotiated_protocol_ == kProtoHTTP2) {
+        if (is_websocket_) {
+          // WebSocket is not supported over a fresh HTTP/2 connection. This
+          // should not be reachable. For the origin, we do not request HTTP/2
+          // on fresh WebSockets connections, because not all HTTP/2 servers
+          // implement RFC 8441. For proxies, WebSockets are always tunneled.
+          //
+          // TODO(davidben): This isn't a CHECK() because, previously, it was
+          // reachable in https://crbug.com/828865. However, if reachable, it
+          // means a bug in the socket pools. The socket pools have since been
+          // cleaned up, so this may no longer be reachable. Restore the CHECK
+          // and see if this is still needed.
+          return ERR_NOT_IMPLEMENTED;
+        }
 
-      // Using unencrypted websockets over an H2 proxy is not currently
-      // supported.
-      // TODO(mmenke): Should this case be treated like
-      // |try_websocket_over_http2_|, or should we force HTTP/1.1?
-      if (is_websocket_ && !try_websocket_over_http2_)
-        return ERR_NOT_IMPLEMENTED;
+        using_spdy_ = true;
+      }
     }
   }
 
@@ -971,6 +968,16 @@ int HttpStreamFactory::Job::DoInitConnectionComplete(int result) {
   if (expect_spdy_ && !using_spdy_)
     return ERR_ALPN_NEGOTIATION_FAILED;
 
+  // |result| may be the result of any of the stacked protocols. The following
+  // logic is used when determining how to interpret an error.
+  // If |result| < 0:
+  //   and connection_->socket() != NULL, then the SSL handshake ran and it
+  //     is a potentially recoverable error.
+  //   and connection_->socket == NULL and connection_->is_ssl_error() is true,
+  //     then the SSL handshake ran with an unrecoverable error.
+  //   otherwise, the error came from one of the other protocols.
+  bool ssl_started = using_ssl_ && (result == OK || connection_->socket() ||
+                                    connection_->is_ssl_error());
   if (!ssl_started && result < 0 && (expect_spdy_ || using_quic_))
     return result;
 
@@ -1051,8 +1058,8 @@ int HttpStreamFactory::Job::SetSpdyHttpStreamOrBidirectionalStreamImpl(
     DCHECK(delegate_->websocket_handshake_stream_create_helper());
 
     if (!try_websocket_over_http2_) {
-      // Plaintext WebSocket is not supported over HTTP/2 proxy,
-      // see https://crbug.com/684681.
+      // TODO(davidben): Is this reachable? We shouldn't receive a SpdySession
+      // if not requested.
       return ERR_NOT_IMPLEMENTED;
     }
 
