@@ -51,12 +51,6 @@ class NET_EXPORT_PRIVATE ProxyClientSocket : public StreamSocket {
   // implementations should disconnect themselves and return OK.
   virtual int RestartWithAuth(CompletionOnceCallback callback) = 0;
 
-  // Returns true of the connection to the proxy is using SPDY.
-  virtual bool IsUsingSpdy() const = 0;
-
-  // Returns the protocol negotiated with the proxy.
-  virtual NextProto GetProxyNegotiatedProtocol() const = 0;
-
   // Set the priority of the underlying stream (for SPDY and QUIC)
   virtual void SetStreamPriority(RequestPriority priority);
 
