@@ -6,6 +6,7 @@
 
 #include <algorithm>
 #include <memory>
+#include <set>
 #include <tuple>
 #include <utility>
 
@@ -20,6 +21,7 @@
 #include "base/metrics/histogram_macros.h"
 #include "base/no_destructor.h"
 #include "base/numerics/safe_conversions.h"
+#include "base/ranges/algorithm.h"
 #include "base/strings/string_number_conversions.h"
 #include "base/strings/string_util.h"
 #include "base/strings/stringprintf.h"
@@ -449,10 +451,10 @@ class QuicStreamFactory::Job {
       return false;
 
     std::vector<net::IPEndPoint> endpoints =
-        fresh_resolve_host_request_->GetAddressResults().value().endpoints();
+        fresh_resolve_host_request_->GetAddressResults()->endpoints();
 
     IPEndPoint stale_address =
-        resolve_host_request_->GetAddressResults().value().front();
+        resolve_host_request_->GetAddressResults()->front();
 
     if (std::find(endpoints.begin(), endpoints.end(), stale_address) !=
         endpoints.end()) {
@@ -641,8 +643,7 @@ void QuicStreamFactory::Job::OnResolveHostComplete(int rv) {
       resolve_host_request_ = std::move(fresh_resolve_host_request_);
       io_state_ = STATE_RESOLVE_HOST_COMPLETE;
     } else if (factory_->HasMatchingIpSession(
-                   key_,
-                   fresh_resolve_host_request_->GetAddressResults().value(),
+                   key_, *fresh_resolve_host_request_->GetAddressResults(),
                    use_dns_aliases_)) {
       // Session with resolved IP has already existed, so close racing
       // connection, run callback, and return.
@@ -800,7 +801,7 @@ int QuicStreamFactory::Job::DoResolveHostComplete(int rv) {
   // Inform the factory of this resolution, which will set up
   // a session alias, if possible.
   if (factory_->HasMatchingIpSession(
-          key_, resolve_host_request_->GetAddressResults().value(),
+          key_, *resolve_host_request_->GetAddressResults(),
           use_dns_aliases_)) {
     LogConnectionIpPooling(true);
     return OK;
@@ -822,9 +823,8 @@ int QuicStreamFactory::Job::DoConnect() {
   DCHECK_NE(quic_version_, quic::ParsedQuicVersion::Unsupported());
   int rv = factory_->CreateSession(
       key_, quic_version_, cert_verify_flags_, require_confirmation,
-      resolve_host_request_->GetAddressResults().value(),
-      dns_resolution_start_time_, dns_resolution_end_time_, net_log_, &session_,
-      &network_);
+      *resolve_host_request_->GetAddressResults(), dns_resolution_start_time_,
+      dns_resolution_end_time_, net_log_, &session_, &network_);
   DVLOG(1) << "Created session on network: " << network_;
 
   if (rv != OK) {
@@ -990,10 +990,10 @@ int QuicStreamFactory::Job::DoConfirmConnection(int rv) {
   }
   LogConnectionIpPooling(false);
 
-  std::vector<std::string> dns_aliases =
+  std::set<std::string> dns_aliases =
       use_dns_aliases_ && resolve_host_request_->GetDnsAliasResults()
-          ? resolve_host_request_->GetDnsAliasResults().value()
-          : std::vector<std::string>();
+          ? *resolve_host_request_->GetDnsAliasResults()
+          : std::set<std::string>();
   factory_->ActivateSession(key_, session_, std::move(dns_aliases));
 
   return OK;
@@ -1684,13 +1684,12 @@ base::TimeDelta QuicStreamFactory::GetTimeDelayForWaitingJob(
   return base::Microseconds(srtt);
 }
 
-const std::vector<std::string>& QuicStreamFactory::GetDnsAliasesForSessionKey(
+const std::set<std::string>& QuicStreamFactory::GetDnsAliasesForSessionKey(
     const QuicSessionKey& key) const {
   auto it = dns_aliases_by_session_key_.find(key);
 
   if (it == dns_aliases_by_session_key_.end()) {
-    static const base::NoDestructor<std::vector<std::string>>
-        emptyvector_result;
+    static const base::NoDestructor<std::set<std::string>> emptyvector_result;
     return *emptyvector_result;
   }
 
@@ -1712,10 +1711,13 @@ bool QuicStreamFactory::HasMatchingIpSession(const QuicSessionAliasKey& key,
         continue;
       active_sessions_[key.session_key()] = session;
 
-      std::vector<std::string> dns_aliases =
-          use_dns_aliases ? dns_alias_utility::SanitizeDnsAliases(
-                                address_list.dns_aliases())
-                          : std::vector<std::string>();
+      std::set<std::string> dns_aliases;
+      if (use_dns_aliases) {
+        base::ranges::copy(address_list.dns_aliases(),
+                           std::inserter(dns_aliases, dns_aliases.end()));
+        dns_aliases = dns_alias_utility::FixUpDnsAliases(dns_aliases);
+      }
+
       MapSessionToAliasKey(session, key, std::move(dns_aliases));
 
       return true;
@@ -1898,7 +1900,7 @@ int QuicStreamFactory::CreateSession(
 
 void QuicStreamFactory::ActivateSession(const QuicSessionAliasKey& key,
                                         QuicChromiumClientSession* session,
-                                        std::vector<std::string> dns_aliases) {
+                                        std::set<std::string> dns_aliases) {
   DCHECK(!HasActiveSession(key.session_key()));
   UMA_HISTOGRAM_COUNTS_1M("Net.QuicActiveSessions", active_sessions_.size());
   active_sessions_[key.session_key()] = session;
@@ -2150,7 +2152,7 @@ void QuicStreamFactory::ProcessGoingAwaySession(
 void QuicStreamFactory::MapSessionToAliasKey(
     QuicChromiumClientSession* session,
     const QuicSessionAliasKey& key,
-    std::vector<std::string> dns_aliases) {
+    std::set<std::string> dns_aliases) {
   session_aliases_[session].insert(key);
   dns_aliases_by_session_key_[key.session_key()] = std::move(dns_aliases);
 }
