@@ -7,14 +7,15 @@
 #include <tuple>
 
 #include "base/check.h"
+#include "build/build_config.h"
 
-#if defined(OS_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
 #include "net/android/network_library.h"
 #endif  // OS_ANDROID
 
 namespace net {
 
-#if defined(OS_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
 // Expose UNSET_UID to Java.
 // GENERATED_JAVA_ENUM_PACKAGE: org.chromium.net
 enum TrafficStatsUid {
@@ -26,7 +27,7 @@ static_assert(UNSET == SocketTag::UNSET_UID,
 #endif  // OS_ANDROID
 
 bool SocketTag::operator<(const SocketTag& other) const {
-#if defined(OS_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
   return std::tie(uid_, traffic_stats_tag_) <
          std::tie(other.uid_, other.traffic_stats_tag_);
 #else
@@ -35,7 +36,7 @@ bool SocketTag::operator<(const SocketTag& other) const {
 }
 
 bool SocketTag::operator==(const SocketTag& other) const {
-#if defined(OS_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
   return std::tie(uid_, traffic_stats_tag_) ==
          std::tie(other.uid_, other.traffic_stats_tag_);
 #else
@@ -44,7 +45,7 @@ bool SocketTag::operator==(const SocketTag& other) const {
 }
 
 void SocketTag::Apply(SocketDescriptor socket) const {
-#if defined(OS_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
   net::android::TagSocket(socket, uid_, traffic_stats_tag_);
 #else
   CHECK(false);
