@@ -339,9 +339,9 @@ const std::string SOCKSClientSocket::BuildHandshakeWriteBuffer() const {
   request.nw_port = base::HostToNet16(destination_.port());
 
   DCHECK(resolve_host_request_->GetAddressResults() &&
-         !resolve_host_request_->GetAddressResults().value().empty());
+         !resolve_host_request_->GetAddressResults()->empty());
   const IPEndPoint& endpoint =
-      resolve_host_request_->GetAddressResults().value().front();
+      resolve_host_request_->GetAddressResults()->front();
 
   // We disabled IPv6 results when resolving the hostname, so none of the
   // results in the list will be IPv6.
