@@ -27,7 +27,7 @@
 
 // PowerMonitor doesn't get suspend mode signals on Android, so don't use it to
 // watch for suspend events.
-#if !defined(OS_ANDROID)
+#if !BUILDFLAG(IS_ANDROID)
 // Define SOCKETS_OBSERVE_SUSPEND if sockets should watch for suspend events so
 // they can fail pending socket operations on suspend. Otherwise, connections
 // hang for varying lengths of time when leaving suspend mode before failing
