@@ -10,7 +10,7 @@
 #include <memory>
 #include <vector>
 
-#include "base/macros.h"
+#include "base/memory/raw_ptr.h"
 #include "base/memory/ref_counted.h"
 #include "base/memory/weak_ptr.h"
 #include "net/base/load_timing_info.h"
@@ -91,8 +91,8 @@ class NET_EXPORT_PRIVATE BidirectionalStreamSpdyImpl
   bool MaybeHandleStreamClosedInSendData();
 
   const base::WeakPtr<SpdySession> spdy_session_;
-  const BidirectionalStreamRequestInfo* request_info_;
-  BidirectionalStreamImpl::Delegate* delegate_;
+  raw_ptr<const BidirectionalStreamRequestInfo> request_info_;
+  raw_ptr<BidirectionalStreamImpl::Delegate> delegate_;
   std::unique_ptr<base::OneShotTimer> timer_;
   SpdyStreamRequest stream_request_;
   base::WeakPtr<SpdyStream> stream_;
