@@ -5,6 +5,7 @@
 #include "net/spdy/spdy_session_pool.h"
 
 #include <algorithm>
+#include <set>
 #include <utility>
 
 #include "base/bind.h"
@@ -153,7 +154,7 @@ int SpdySessionPool::CreateAvailableSessionFromSocketHandle(
 
   std::unique_ptr<SpdySession> new_session =
       CreateSession(key, net_log.net_log());
-  std::vector<std::string> dns_aliases =
+  std::set<std::string> dns_aliases =
       client_socket_handle->socket()->GetDnsAliases();
 
   new_session->InitializeWithSocketHandle(std::move(client_socket_handle),
@@ -187,7 +188,7 @@ base::WeakPtr<SpdySession> SpdySessionPool::CreateAvailableSessionFromSocket(
 
   std::unique_ptr<SpdySession> new_session =
       CreateSession(key, net_log.net_log());
-  std::vector<std::string> dns_aliases = socket_stream->GetDnsAliases();
+  std::set<std::string> dns_aliases = socket_stream->GetDnsAliases();
 
   new_session->InitializeWithSocket(std::move(socket_stream), connect_timing,
                                     this);
@@ -345,7 +346,7 @@ OnHostResolutionCallbackResult SpdySessionPool::OnHostResolutionComplete(
           adding_pooled_alias = false;
 
         // Remap main session key.
-        std::vector<std::string> main_session_old_dns_aliases =
+        std::set<std::string> main_session_old_dns_aliases =
             GetDnsAliasesForSessionKey(old_key);
         UnmapKey(old_key);
         MapKeyToAvailableSession(new_key, available_session,
@@ -365,7 +366,7 @@ OnHostResolutionCallbackResult SpdySessionPool::OnHostResolutionComplete(
             continue;
           }
 
-          std::vector<std::string> pooled_alias_old_dns_aliases =
+          std::set<std::string> pooled_alias_old_dns_aliases =
               GetDnsAliasesForSessionKey(*it);
           UnmapKey(*it);
           SpdySessionKey new_pool_alias_key = SpdySessionKey(
@@ -388,12 +389,14 @@ OnHostResolutionCallbackResult SpdySessionPool::OnHostResolutionComplete(
 
       if (adding_pooled_alias) {
         // Sanitize DNS aliases so that they can be added to the DNS alias map.
-        std::vector<std::string> sanitized_dns_aliases =
-            dns_alias_utility::SanitizeDnsAliases(addresses.dns_aliases());
+        std::set<std::string> fixed_dns_aliases =
+            dns_alias_utility::FixUpDnsAliases(
+                std::set<std::string>(addresses.dns_aliases().begin(),
+                                      addresses.dns_aliases().end()));
 
         // Add this session to the map so that we can find it next time.
         MapKeyToAvailableSession(key, available_session,
-                                 std::move(sanitized_dns_aliases));
+                                 std::move(fixed_dns_aliases));
         available_session->AddPooledAlias(key);
       }
 
@@ -526,7 +529,7 @@ void SpdySessionPool::OnSSLConfigForServerChanged(const HostPortPair& server) {
   }
 }
 
-std::vector<std::string> SpdySessionPool::GetDnsAliasesForSessionKey(
+std::set<std::string> SpdySessionPool::GetDnsAliasesForSessionKey(
     const SpdySessionKey& key) const {
   auto it = dns_aliases_by_session_key_.find(key);
   if (it == dns_aliases_by_session_key_.end())
@@ -571,7 +574,7 @@ bool SpdySessionPool::IsSessionAvailable(
 void SpdySessionPool::MapKeyToAvailableSession(
     const SpdySessionKey& key,
     const base::WeakPtr<SpdySession>& session,
-    std::vector<std::string> dns_aliases) {
+    std::set<std::string> dns_aliases) {
   DCHECK(base::Contains(sessions_, session.get()));
   std::pair<AvailableSessionMap::iterator, bool> result =
       available_sessions_.insert(std::make_pair(key, session));
@@ -672,7 +675,7 @@ base::WeakPtr<SpdySession> SpdySessionPool::InsertSession(
     const SpdySessionKey& key,
     std::unique_ptr<SpdySession> new_session,
     const NetLogWithSource& source_net_log,
-    std::vector<std::string> dns_aliases) {
+    std::set<std::string> dns_aliases) {
   base::WeakPtr<SpdySession> available_session = new_session->GetWeakPtr();
   sessions_.insert(new_session.release());
   MapKeyToAvailableSession(key, available_session, std::move(dns_aliases));
