@@ -353,9 +353,9 @@ class NET_EXPORT URLFetcher {
   // annotations on Linux & Windows.
 // TODO(crbug.com/1052397): Revisit once build flag switch of lacros-chrome is
 // complete.
-#if (!defined(OS_WIN) &&                                       \
-     !(defined(OS_LINUX) || BUILDFLAG(IS_CHROMEOS_LACROS))) || \
-    defined(OS_CHROMEOS)
+#if (!BUILDFLAG(IS_WIN) &&                                       \
+     !(BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS_LACROS))) || \
+    BUILDFLAG(IS_CHROMEOS)
   // |url| is the URL to send the request to. It must be valid.
   // |request_type| is the type of request to make.
   // |d| the object that will receive the callback on fetch completion.
