@@ -25,14 +25,14 @@
 #include "net/base/load_states.h"
 #include "net/base/load_timing_info.h"
 #include "net/base/net_error_details.h"
+#include "net/base/net_errors.h"
 #include "net/base/net_export.h"
 #include "net/base/network_delegate.h"
-#include "net/base/privacy_mode.h"
 #include "net/base/proxy_server.h"
 #include "net/base/request_priority.h"
 #include "net/base/upload_progress.h"
 #include "net/cookies/canonical_cookie.h"
-#include "net/cookies/same_party_context.h"
+#include "net/cookies/first_party_set_metadata.h"
 #include "net/cookies/site_for_cookies.h"
 #include "net/dns/public/secure_dns_policy.h"
 #include "net/filter/source_stream.h"
@@ -278,13 +278,13 @@ class NET_EXPORT URLRequest : public base::SupportsUserData {
   }
   const IsolationInfo& isolation_info() const { return isolation_info_; }
 
-  // The party_context_ of this leg of the request. This gets updated on
-  // redirects.
-  const SamePartyContext& same_party_context() const {
-    return same_party_context_;
+  // The First-Party Set metadata of this leg of the request. This gets updated
+  // on redirects.
+  const FirstPartySetMetadata& first_party_set_metadata() const {
+    return first_party_set_metadata_;
   }
-  void set_same_party_context(const SamePartyContext& context) {
-    same_party_context_ = context;
+  void set_first_party_set_metadata(FirstPartySetMetadata metadata) {
+    first_party_set_metadata_ = std::move(metadata);
   }
 
   // Indicate whether SameSite cookies should be attached even though the
@@ -555,10 +555,6 @@ class NET_EXPORT URLRequest : public base::SupportsUserData {
   // Access the LOAD_* flags modifying this request (see load_flags.h).
   int load_flags() const { return load_flags_; }
 
-  // Returns PrivacyMode that should be used for the request. Updated every time
-  // the request is redirected.
-  PrivacyMode privacy_mode() const { return privacy_mode_; }
-
   // Returns the Secure DNS Policy for the request.
   SecureDnsPolicy secure_dns_policy() const { return secure_dns_policy_; }
 
@@ -799,12 +795,15 @@ class NET_EXPORT URLRequest : public base::SupportsUserData {
   void set_send_client_certs(bool send_client_certs) {
     send_client_certs_ = send_client_certs;
   }
+  bool send_client_certs() const { return send_client_certs_; }
 
   bool is_for_websockets() const { return is_for_websockets_; }
 
   void SetIdempotency(Idempotency idempotency) { idempotency_ = idempotency; }
   Idempotency GetIdempotency() const { return idempotency_; }
 
+  static bool DefaultCanUseCookies();
+
   base::WeakPtr<URLRequest> GetWeakPtr();
 
  protected:
@@ -892,23 +891,26 @@ class NET_EXPORT URLRequest : public base::SupportsUserData {
                                  bool fatal);
   void NotifyReadCompleted(int bytes_read);
 
-  // These functions delegate to the NetworkDelegate if it is not nullptr.
+  // This function delegates to the NetworkDelegate if it is not nullptr.
   // Otherwise, cookies can be used unless SetDefaultCookiePolicyToBlock() has
   // been called.
-  void AnnotateAndMoveUserBlockedCookies(
-      CookieAccessResultList& maybe_included_cookies,
-      CookieAccessResultList& excluded_cookies) const;
   bool CanSetCookie(const net::CanonicalCookie& cookie,
                     CookieOptions* options) const;
-  PrivacyMode DeterminePrivacyMode() const;
 
   // Called just before calling a delegate that may block a request. |type|
   // should be the delegate's event type,
   // e.g. NetLogEventType::NETWORK_DELEGATE_AUTH_REQUIRED.
   void OnCallToDelegate(NetLogEventType type);
   // Called when the delegate lets a request continue.  Also called on
-  // cancellation.
-  void OnCallToDelegateComplete();
+  // cancellation. `error` is an optional error code associated with
+  // completion. It's only for logging purposes, and will not directly cancel
+  // the request if it's a value other than OK.
+  void OnCallToDelegateComplete(int error = OK);
+
+  // Called after getting First-Party Set metadata, when starting a request leg.
+  void OnGotFirstPartySetMetadata(
+      std::unique_ptr<URLRequestJob> job,
+      FirstPartySetMetadata first_party_set_metadata);
 
   // Records the referrer policy of the given request, bucketed by
   // whether the request is same-origin or not. To save computation,
@@ -932,7 +934,7 @@ class NET_EXPORT URLRequest : public base::SupportsUserData {
 
   IsolationInfo isolation_info_;
 
-  SamePartyContext same_party_context_;
+  FirstPartySetMetadata first_party_set_metadata_;
 
   bool force_ignore_site_for_cookies_;
   bool force_ignore_top_frame_party_for_cookies_;
@@ -950,11 +952,6 @@ class NET_EXPORT URLRequest : public base::SupportsUserData {
   // Whether the request is allowed to send credentials in general. Set by
   // caller.
   bool allow_credentials_;
-  // Privacy mode for current hop. Based on |allow_credentials_|, |load_flags_|,
-  // and information provided by the NetworkDelegate. Saving cookies can
-  // currently be blocked independently of this field by setting the deprecated
-  // LOAD_DO_NOT_SAVE_COOKIES field in |load_flags_|.
-  PrivacyMode privacy_mode_;
   SecureDnsPolicy secure_dns_policy_;
 
   CookieAccessResultList maybe_sent_cookies_;
