@@ -35,6 +35,7 @@
 #include "net/dns/host_resolver.h"
 #include "net/http/http_network_session.h"
 #include "net/net_buildflags.h"
+#include "net/network_error_logging/network_error_logging_service.h"
 #include "net/proxy_resolution/proxy_config_service.h"
 #include "net/proxy_resolution/proxy_resolution_service.h"
 #include "net/ssl/ssl_config_service.h"
@@ -119,7 +120,7 @@ class NET_EXPORT URLRequestContextBuilder {
     // The cache path (when type is DISK).
     base::FilePath path;
 
-#if defined(OS_ANDROID)
+#if BUILDFLAG(IS_ANDROID)
     // If this is set, will override the default ApplicationStatusListener. This
     // is useful if the cache will not be in the main process.
     raw_ptr<base::android::ApplicationStatusListener> app_status_listener =
@@ -150,7 +151,8 @@ class NET_EXPORT URLRequestContextBuilder {
   // associated HttpNetworkSession are consistent.
   static void SetHttpNetworkSessionComponents(
       const URLRequestContext* request_context,
-      HttpNetworkSessionContext* session_context);
+      HttpNetworkSessionContext* session_context,
+      bool suppress_setting_socket_performance_watcher_factory = false);
 
   // These functions are mutually exclusive.  The ProxyConfigService, if
   // set, will be used to construct a ConfiguredProxyResolutionService.
@@ -229,8 +231,11 @@ class NET_EXPORT URLRequestContextBuilder {
   // Uses NetworkDelegateImpl by default. Note that calling Build will unset
   // any custom delegate in builder, so this must be called each time before
   // Build is called.
-  void set_network_delegate(std::unique_ptr<NetworkDelegate> delegate) {
+  // Returns a raw pointer to the set delegate.
+  template <typename T>
+  T* set_network_delegate(std::unique_ptr<T> delegate) {
     network_delegate_ = std::move(delegate);
+    return static_cast<T*>(network_delegate_.get());
   }
 
   // Sets the ProxyDelegate.
@@ -269,6 +274,9 @@ class NET_EXPORT URLRequestContextBuilder {
   void set_throttling_enabled(bool throttling_enabled) {
     throttling_enabled_ = throttling_enabled;
   }
+  void set_first_party_sets_enabled(bool enabled) {
+    first_party_sets_enabled_ = enabled;
+  }
 
   void set_ct_policy_enforcer(
       std::unique_ptr<CTPolicyEnforcer> ct_policy_enforcer);
@@ -285,6 +293,12 @@ class NET_EXPORT URLRequestContextBuilder {
     network_error_logging_enabled_ = network_error_logging_enabled;
   }
 
+  template <typename T>
+  T* SetNetworkErrorLoggingServiceForTesting(std::unique_ptr<T> service) {
+    network_error_logging_service_ = std::move(service);
+    return static_cast<T*>(network_error_logging_service_.get());
+  }
+
   void set_persistent_reporting_and_nel_store(
       std::unique_ptr<PersistentReportingAndNelStore>
           persistent_reporting_and_nel_store);
@@ -319,6 +333,10 @@ class NET_EXPORT URLRequestContextBuilder {
   // safely destroyed.
   std::unique_ptr<URLRequestContext> Build();
 
+  void SuppressSettingSocketPerformanceWatcherFactoryForTesting() {
+    suppress_setting_socket_performance_watcher_factory_for_testing_ = true;
+  }
+
  protected:
   // Lets subclasses override ProxyResolutionService creation, using a
   // ProxyResolutionService that uses the URLRequestContext itself to get PAC
@@ -343,6 +361,8 @@ class NET_EXPORT URLRequestContextBuilder {
   bool http_cache_enabled_ = true;
   bool throttling_enabled_ = false;
   bool cookie_store_set_by_client_ = false;
+  bool suppress_setting_socket_performance_watcher_factory_for_testing_ = false;
+  bool first_party_sets_enabled_ = false;
 
   HttpCacheParams http_cache_params_;
   HttpNetworkSessionParams http_network_session_params_;
@@ -369,6 +389,7 @@ class NET_EXPORT URLRequestContextBuilder {
 #if BUILDFLAG(ENABLE_REPORTING)
   std::unique_ptr<ReportingPolicy> reporting_policy_;
   bool network_error_logging_enabled_ = false;
+  std::unique_ptr<NetworkErrorLoggingService> network_error_logging_service_;
   std::unique_ptr<PersistentReportingAndNelStore>
       persistent_reporting_and_nel_store_;
 #endif  // BUILDFLAG(ENABLE_REPORTING)
