@@ -21,6 +21,7 @@
 #include "net/base/ip_endpoint.h"
 #include "net/base/net_error_details.h"
 #include "net/base/net_export.h"
+#include "net/base/privacy_mode.h"
 #include "net/cookies/cookie_inclusion_status.h"
 #include "net/http/http_request_info.h"
 #include "net/socket/connection_attempts.h"
@@ -110,8 +111,15 @@ class NET_EXPORT_PRIVATE URLRequestHttpJob : public URLRequestJob {
 
   void DestroyTransaction();
 
+  // Computes the PrivacyMode that should be associated with this leg of the
+  // request. Must be recomputed on redirects.
+  PrivacyMode DeterminePrivacyMode() const;
+
   void AddExtraHeaders();
   void AddCookieHeaderAndStart();
+  void AnnotateAndMoveUserBlockedCookies(
+      CookieAccessResultList& maybe_included_cookies,
+      CookieAccessResultList& excluded_cookies) const;
   void SaveCookiesAndNotifyHeadersComplete(int result);
 
   // Processes the Strict-Transport-Security header, if one exists.
@@ -206,13 +214,16 @@ class NET_EXPORT_PRIVATE URLRequestHttpJob : public URLRequestJob {
   // `override_response_info_::headers`.
   HttpResponseHeaders* GetResponseHeaders() const;
 
-  // Compute the `cookie_partition_key_` for the request. Partitioned cookies
-  // will be set using this key and only partitioned cookies with this partition
-  // key will be sent.
-  // Sets `cookie_partition_key_` to nullopt if cookie partitioning is not
-  // enabled, if the NIK has no top-frame site, or if the instance has no
-  // cookie store.
-  void ComputeCookiePartitionKey();
+  // Computes the cookie partition key for the request. Partitioned cookies
+  // should be set using this key and only partitioned cookies with this
+  // partition key should be sent.
+  // Returns nullopt if cookie partitioning is not enabled, if the NIK has no
+  // top-frame site, or if the instance has no cookie store.
+  absl::optional<CookiePartitionKey> ComputeCookiePartitionKey();
+
+  // Returns true if partitioned cookies are enabled and can be accessed and/or
+  // set.
+  bool IsPartitionedCookiesEnabled() const;
 
   RequestPriority priority_;
 
