@@ -8,6 +8,8 @@ See http://dev.chromium.org/developers/how-tos/depottools/presubmit-scripts for
 details on the presubmit API built into gcl.
 """
 
+USE_PYTHON3 = True
+
 
 def RunUnittests(input_api, output_api):
   presubmit_path = input_api.PresubmitLocalPath()
@@ -18,7 +20,8 @@ def RunUnittests(input_api, output_api):
           input_api.os_path.join(input_api.PresubmitLocalPath(),
                                  'preprocess_if_expr_test.py')
       ],
-      run_on_python3=False)  # See https://crbug.com/1145395.
+      run_on_python2=False,
+      skip_shebang_check=True)
 
 
 def CheckChangeOnUpload(input_api, output_api):
